
use "$data/DNB_Panel.dta", clear

		
		
********************************************************************************
*** Comparing Samples born at or before 1800
********************************************************************************		

eststo clear
local cent = 18
*
* Binary:
*
qui foreach var of varlist  ADB NonRoyalReligion Post_NDB {
		
	eststo: reghdfe `var'_D School_Dummy ///
		if Century<=`cent' ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
	
		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'			
		estadd scalar cent = `cent'*100
}
*
* Log:
*
qui foreach var of varlist  ADB NonRoyalReligion Post_NDB {	
	eststo: reghdfe ln`var' School_Dummy ///
		if Century<=`cent' ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"

		su `var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		estadd scalar cent = `cent'*100
}	
*
* Share:
*
qui foreach var of varlist  ADB NonRoyalReligion Post_NDB {	
	eststo: reghdfe Share_`var' School_Dummy ///
		if Century<=`cent' ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"

		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'
		estadd scalar cent = `cent'*100
	 
}
*
// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education psmatch ///
		r2_a N MEAN cent, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" ///
		"Adj. R2" "Observations" "Mean" "Born before:") fmt(a a a a a %9.3f %9.0fc %9.3f %9.0f)) ///
		coeflabels (School "Finishing school\(\_it\)" )
	// for export

	esttab using "$tables/AppA_1800.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _) 
	

// bring panels together
		#delimit ;
		esttab using "$tables/A1_Panel.tex", replace booktabs
			cells(none) nonote noobs mtitle("ADB" "NDB" "Post-NDB" "ADB" "NDB" "Post-NDB" "ADB" "NDB" "Post-NDB")  ///
			mgroups("\$\mathbb{I}[Women>0]\$" "log Women" "Share Women", pattern(1 0 0 1 0 0 1 0 0 ) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\panelinput{"Tables/AppA_1800"} 
			 \midrule )
			substitute(\_ _)	
		stats(localitytrend econ rel education psmatch N MEAN cent ///
		, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Matching on 1600 covariates" "Observations" "Mean" "Included if born before: ") fmt(a a a a a %9.0fc %9.3fc %9.0f )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr				

****************************************************
// ------------------------------------------------
// Distribution of notable women over time  //
// ------------------------------------------------
****************************************************

use "$data/DNB_Population.dta", clear

twoway (line Population Century , sort) (line Men Century, sort yaxis(2))  (line Women Century, sort yaxis(3)) ///
		, legend(order(1 "Population" 2 "Men" 3 "Women") pos(6) rows(1)) yscale(axis(3) alt) yscale(axis(2) alt) xtitle(Year) ytitle("Population in Millions")  xlabel(800(50)1850, labels angle(ninety))
	
graph export "$figures/A1a_Figure.png", replace width(2000)
		
			

twoway (line Population Century , sort) (line Men_Share Century , sort yaxis(2))  (line Women_Share Century , sort yaxis(2)) ///
		, legend(order(1 "Population" 2 "Men" 3 "Women") pos(6) rows(1)) ytitle("Fraction of Men/Women reported", axis(2)) xtitle(Year) ytitle("Population in Millions") xlabel(800(50)1850, labels angle(ninety))
		
		

graph export "$figures/A1b_Figure.png", replace width(2000)
						


use "$data/DNB_Panel.dta", clear

cap drop *_Royal_Pop 
gen Size_Royal_Pop = (Royals+M_Royals)/(Pop_Panel+1)
gen Women_Royal_Pop = (Royals)/(Pop_Panel+1)
gen Men_Royal_Pop= (M_Royals)/(Pop_Panel+1)
		
twoway (lpoly Women_Royal_Pop Century  if Century>=10) (lpoly Men_Royal_Pop Century  if Century>=10) (lpoly Size_Royal_Pop Century  if Century>=10) ///
	, legend(pos(6) order(1 "Women" 2 "Men" 3 "Total") rows(1))	title("Noble Population per Capita") ytitle(Noble / Population)	xtitle(Century)
graph export "$figures/A2_Figure.png", replace width(2000)
		
				
		
		
****************************************************
// ------------------------------------------------
// Create Summary Statistics  //
// ------------------------------------------------
****************************************************

	

use "$data/DNB_Panel.dta", clear
tempfile base data coor 
mat m = J(17,3,.)

/************************************************
Summary statistic neue deutsche biographie
************************************************/

shp2dta using "$data/NDB_2022.shp" ///
	, data(`data') coor(`coor') replace

use "$data/NDB_2022.dta", clear

// gen Married = (ever_married==1)
// gen Writer = (Beruf==11)

merge 1:m pers_id using `data', force	
	

keep if _merge==3
drop _merge

save `base', replace


shp2dta using "$data/TH1300_Schools.shp" ///
	, data(`data') coor(`coor') replace

use `data', clear

gen School = Join_Count
gen No_School=Join_Count
collapse   (max) School (sum) No_School, by(town_id )



	su No_School if School==0
	mat m[1,1] = `r(mean)'
	su No_School if School==1
	mat m[1,2] = `r(mean)'



merge 1:m town_id using `base'

count if _merge==3
local ndb = `r(N)'

local n = 1
egen help = rowmax(Academic Artist Grunder Medicine Occupations Politics Sports Teacher Writer Activist  Royals Religion)
gen Unknown = (help==0)
gen NRR = (Religion==0&Royals==0)
local list Academic Artist Grunder Medicine Occupations Politics Sports Teacher Unknown Writer Activist /*Unmarried */ Royals Religion NRR

foreach var of varlist `list'  {
	local n = `n'+1
	di "`var'"
	count if `var'==1&School==0
	mat m[`n',1] = `r(N)'
	count if `var'==1&School==1
	mat m[`n',2] = `r(N)'
	count if `var'==1
	mat m[`n',3] = `r(N)'/`ndb'

}

mat list m


use "$data/DNB_Panel.dta", clear

foreach var of varlist Pop_1600 Pop_1850 {
	local n = `n'+1
	di "`var'"
	su `var' if School==0
	mat m[`n',1] = `r(mean)'
	su `var' if School==1
	mat m[`n',2] = `r(mean)'
	

}



mat colnames m = "Without finishing schools" "With finishing schools" "Percent of sample"
mat rownames m = "Finishing Schools" `list' "Population"
mat list m


esttab matrix(m,fmt(%9.1g %9.1g %9.3f)) using "$tables/A2_Panel" ///
			, replace booktabs nomtitles  ///
			mgroups("Cities", pattern(0 1 0) ///
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))



	su Pop_1600 if School==0
	local m1 = `r(mean)'
	su Pop_1600 if School==1
	local m2 = `r(mean)'
	su Pop_1850 if School==0
	local m3 = `r(mean)'
	su Pop_1850 if School==1
	local m4 = `r(mean)'
	
* within time across cities
 di `m2'/`m1'
 di `m4'/`m3'
 
* within cities, across time
 di `m3'/`m1'
 di `m4'/`m2'