
use "$data/DNB_Panel.dta", clear

cap drop LaborForce_Participation LaborForce_Participation_D Share_LaborForce_Participation lnLaborForce_Participation
egen LaborForce_Participation = rowtotal(Occupations Medicine Teacher Academic Writer )
gen LaborForce_Participation_D = (LaborForce_Participation>0) if LaborForce_Participation!=.
gen Share_LaborForce_Participation = (LaborForce_Participation)/(LaborForce_Participation+M_Occupation+1)
gen lnLaborForce_Participation = log(LaborForce_Participation+1)


******************************************************
* Binary
******************************************************

foreach var of varlist  NonRoyalReligion    {

	eststo clear
	qui {
		
		
		
		* FE DUMMY
		* Plain Vanilla
		 eststo: reghdfe `var'_D School_Dummy ,a(Century town_id ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'		
		
		* Linear TT
		 eststo: reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding economic cov.	
		eststo: reghdfe `var'_D School_Dummy ///
			,a(Century town_id ///
			Hanse##Century  Jewish##Century Progrom##Century /// 
			Battle##Century  ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel ""
			estadd local education ""

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		* Adding education cov.	
		eststo: reghdfe `var'_D School_Dummy ///
			,a(Century town_id ///
			OldSchool##Century Uni_1650#Century ///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education "Yes"

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding religious cov.		
		eststo: reghdfe `var'_D School_Dummy ///
			,a(Century town_id ///
			 bishop##Century  /// 
			 c.lnDW##Century ///
			 ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel "Yes"
			estadd local education ""

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	

		
			
		* Taking out linear time trend	
		eststo: reghdfe `var'_D School_Dummy ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
				
* Adding all 	
		eststo: reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'										
				
		
		
		 
	}
		// for inspection
		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
			stats(localitytrend econ  education rel ///
			r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
			 "Educational covariates \(\times\) period FE" "Religious covariates \(\times\) period FE" ///
			"Adj. R2" "Observations" "Mean") fmt(a a a a  %9.3f %9.0fc %9.3f)) ///
			coeflabels (School "Finishing school\(\_it\)" )
		/// for export	
		esttab using "$tables/B1_`var'_APP_LT_Dummy.tex" ///
				, replace booktabs fragment ///
				star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
				coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
				nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
				substitute(\_ _) ///
				
		*/
	}

******************************************************
*LOG
******************************************************


foreach var of varlist  NonRoyalReligion  {

	eststo clear
	qui {
		
		
		
		* FE DUMMY
		* Plain Vanilla
		 eststo: reghdfe ln`var' School_Dummy ,a(Century town_id ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'		
		
		* Linear TT
		 eststo: reghdfe ln`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding economic cov.	
		eststo: reghdfe ln`var' School_Dummy ///
			,a(Century town_id ///
			Hanse##Century  Jewish##Century Progrom##Century /// 
			Battle##Century  ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel ""
			estadd local education ""

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		* Adding education cov.	
		eststo: reghdfe ln`var' School_Dummy ///
			,a(Century town_id ///
			OldSchool##Century Uni_1650#Century ///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education "Yes"

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding religious cov.		
		eststo: reghdfe ln`var' School_Dummy ///
			,a(Century town_id ///
			 bishop##Century  /// 
			 c.lnDW##Century ///
			 ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel "Yes"
			estadd local education ""

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	

		
			
		* Taking out linear time trend	
		eststo: reghdfe ln`var' School_Dummy ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
				
* Adding all 	
		eststo: reghdfe ln`var' School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'										
				
			* FE Log
		
		 
	}
		// for inspection
		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
			stats(localitytrend econ  education rel ///
			r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
			 "Educational covariates \(\times\) period FE" "Religious covariates \(\times\) period FE" ///
			"Adj. R2" "Observations" "Mean") fmt(a a a a  %9.3f %9.0fc %9.3f)) ///
			coeflabels (School "Finishing school\(\_it\)" )
		/// for export	
		esttab using "$tables/B1_`var'_APP_LT_Log.tex" ///
				, replace booktabs fragment ///
				star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
				coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
				nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
				substitute(\_ _) ///
				
		*/
	}		
	
******************************************************
* Share
******************************************************		

foreach var of varlist  NonRoyalReligion   {

	eststo clear
	qui {
		
		
		
		* FE DUMMY
		* Plain Vanilla
		 eststo: reghdfe Share_`var' School_Dummy ,a(Century town_id ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'		
		
		* Linear TT
		 eststo: reghdfe Share_`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding economic cov.	
		eststo: reghdfe Share_`var' School_Dummy ///
			,a(Century town_id ///
			Hanse##Century  Jewish##Century Progrom##Century /// 
			Battle##Century  ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel ""
			estadd local education ""

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		* Adding education cov.	
		eststo: reghdfe Share_`var' School_Dummy ///
			,a(Century town_id ///
			OldSchool##Century Uni_1650#Century ///
			) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel ""
			estadd local education "Yes"

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
		
		* Adding religious cov.		
		eststo: reghdfe Share_`var' School_Dummy ///
			,a(Century town_id ///
			 bishop##Century  /// 
			 c.lnDW##Century ///
			 ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ ""
			estadd local rel "Yes"
			estadd local education ""

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	

		
			
		* Taking out linear time trend	
		eststo: reghdfe Share_`var' School_Dummy ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend ""
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	
				
* Adding all 	
		eststo: reghdfe Share_`var' School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

			
			estadd local localityFE "Yes"
			estadd local localitytrend "Yes"
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

			su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'										
				
			* FE Log
	
		
		
		 
	}
		// for inspection
		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
			stats(localitytrend econ  education rel ///
			r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
			 "Educational covariates \(\times\) period FE" "Religious covariates \(\times\) period FE" ///
			"Adj. R2" "Observations" "Mean") fmt(a a a a  %9.3f %9.0fc %9.3f)) ///
			coeflabels (School "Finishing school\(\_it\)" )
		/// for export	
		esttab using "$tables/B1_`var'_APP_LT_Share.tex" ///
				, replace booktabs fragment ///
				star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
				coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
				nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
				substitute(\_ _) ///
				
		*/
	}		
	
		

// bring panels together
		#delimit ;
		esttab using "$tables/B1_Panel_All_Specifications.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("Baseline" "with trends" "with covariates" "Full", pattern(1 1 1 0 0 0 1) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Non-Noble Seculars, \$\mathbb{I}[Women>0]\$}} \\ 
			\panelinput{"Tables/B1_NonRoyalReligion_APP_LT_Dummy"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel B: Non-Noble Seculars, log Women}} \\ 
			\panelinput{"Tables/B1_NonRoyalReligion_APP_LT_Log"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel C: Non-Noble Seculars, Share Women}} \\ 
			\panelinput{"Tables/B1_NonRoyalReligion_APP_LT_Share"} 
			 \midrule )
			substitute(\_ _)	
		stats(localitytrend econ education rel ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		 "Educational covariates \(\times\) period FE" "Religious covariates \(\times\) period FE" ///
		"Observations" ) fmt(a a a a  %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr
		
		

********************************************
***	Panel Sensitivity (Main outcome)
********************************************
use "$data/DNB_Panel.dta", clear
preserve
	keep if Century==18.5
	gen n = 1
	collapse (sum) n ,by(MR_2)
	su n, det
	tab n
restore
	

levelsof MR_2 if Schools!=0, local(list)
unique MR_2 if Schools!=0
local row `r(unique)'

foreach var of varlist  NonRoyalReligion  {

mat SENS_`var' = J(`row',7,.)
local n = 1

qui foreach t of local list {
    preserve
		drop if MR_2==`t'


		mat SENS_`var'[`n',1] = `t'
		reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		mat SENS_`var'[`n',2] = _b[School_Dummy]
		
		reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		mat SENS_`var'[`n',3] = _b[School_Dummy]
	 
		reghdfe ln`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		mat SENS_`var'[`n',4] = _b[School_Dummy]	
			
		reghdfe ln`var' School_Dummy ///
					,a(Century town_id##c.Century ///
					Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
					Battle##Century c.lnDW##Century ///
					c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
					c.Winter_1650##Century ///
					c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
					MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		mat SENS_`var'[`n',5] = _b[School_Dummy]
				
						
			* FE Share

		reghdfe Share_`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		mat SENS_`var'[`n',6] = _b[School_Dummy]			
							
		reghdfe Share_`var' School_Dummy ///
					,a(Century town_id##c.Century  ///
					Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
					Battle##Century c.lnDW##Century ///
					c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
					c.Winter_1650##Century ///
					c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
					MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 		
		mat SENS_`var'[`n',7] = _b[School_Dummy]
		local ++n
		restore
}
mat list SENS_`var'
}



local var  = "NonRoyalReligion"
cap drop var1-var7
{
svmat SENS_`var', names(var)

	reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var2 = var2/_b[School_Dummy]
	
	reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	replace var3 = var3/_b[School_Dummy]
	
	reghdfe ln`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var4 = var4/_b[School_Dummy]
	
	reghdfe ln`var' School_Dummy ///
					,a(Century town_id##c.Century ///
					Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
					Battle##Century c.lnDW##Century ///
					c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
					c.Winter_1650##Century ///
					c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
					MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 	
	replace var5 = var5/_b[School_Dummy]
	
						
						
			* FE Share

		reghdfe Share_`var' School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		replace var6 = var6/_b[School_Dummy]			
							
		reghdfe Share_`var' School_Dummy ///
					,a(Century town_id##c.Century  ///
					Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
					Battle##Century c.lnDW##Century ///
					c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
					c.Winter_1650##Century ///
					c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
					MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		replace var7 = var7/_b[School_Dummy]
	
		twoway (histogram var2,  percent bin(10)) ,xtitle("Non-noble Secular, baseline") ytitle("") 
		graph save  "$figures/B1_`var'_2.gph", replace
		twoway (histogram var3,  percent bin(10)) ,xtitle("Non-noble Secular, w. control") ytitle("") 
		graph save  "$figures/B1_`var'_3.gph", replace
		twoway (histogram var4,  percent bin(10)) ,xtitle("log Non-noble Secular, baseline") ytitle("") 
		graph save  "$figures/B1_`var'_4.gph", replace
		twoway (histogram var5,  percent bin(10)) ,xtitle("log Non-noble Secular, w. controls") ytitle("") 
		graph save  "$figures/B1_`var'_5.gph", replace
		twoway (histogram var6,  percent bin(10)) ,xtitle("Share Non-noble Secular, baseline") ytitle("") 
		graph save  "$figures/B1_`var'_6.gph", replace
		twoway (histogram var7,  percent bin(10)) ,xtitle("Share Non-noble Secular, w. controls") ytitle("") 
		graph save  "$figures/B1_`var'_7.gph", replace
}	


*** combine

graph combine 	 "$figures/B1_NonRoyalReligion_2.gph"  "$figures/B1_NonRoyalReligion_4.gph" "$figures/B1_NonRoyalReligion_6.gph" ///
				 "$figures/B1_NonRoyalReligion_3.gph"  "$figures/B1_NonRoyalReligion_5.gph" "$figures/B1_NonRoyalReligion_7.gph" ///
					, rows(2) cols(3) xcommon ycommon
				
graph export "$figures/B1a_Sensitivity_Panel.png", replace width(1000)

********************************************
***	Panel Sensitivity (Additional outcomes)
********************************************
use "$data/DNB_Panel.dta", clear
cap drop LaborForce_Participation LaborForce_Participation_D Share_LaborForce_Participation lnLaborForce_Participation
egen LaborForce_Participation = rowtotal(Occupations Medicine Teacher Academic Writer )
gen LaborForce_Participation_D = (LaborForce_Participation>0) if LaborForce_Participation!=.
gen Share_LaborForce_Participation = (LaborForce_Participation)/(LaborForce_Participation+M_Occupation+1)
gen lnLaborForce_Participation = log(LaborForce_Participation+1)



preserve
	keep if Century==18.5
	gen n = 1
	collapse (sum) n ,by(MR_2)
	su n, det
	tab n
restore
	

levelsof MR_2 if Schools!=0, local(list)
unique MR_2 if Schools!=0
local row `r(unique)'

foreach var of varlist  Writer Activist LaborForce_Participation Connections {

mat SENS_`var' = J(`row',7,.)
local n = 1

qui foreach t of local list {
    preserve
		drop if MR_2==`t'


		mat SENS_`var'[`n',1] = `t'
		reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		mat SENS_`var'[`n',2] = _b[School_Dummy]
		
		reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		mat SENS_`var'[`n',3] = _b[School_Dummy]
	 
		
		local ++n
		restore
}
mat list SENS_`var'
}



local var  = "Writer"
cap drop var1-var7
{
svmat SENS_`var', names(var)

	reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var2 = var2/_b[School_Dummy]
	
	reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	replace var3 = var3/_b[School_Dummy]
	
	twoway (histogram var2,  percent bin(10)) ,xtitle("Writer, baseline") ytitle("") 
	graph save  "$figures/B1_`var'_2.gph", replace
	twoway (histogram var3,  percent bin(10)) ,xtitle("Writer, w. control") ytitle("") 
	graph save  "$figures/B1_`var'_3.gph", replace

}	



local var  = "Activist"
cap drop var1-var7
{
svmat SENS_`var', names(var)

	reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var2 = var2/_b[School_Dummy]
	
	reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	replace var3 = var3/_b[School_Dummy]
	
	twoway (histogram var2,  percent bin(10)) ,xtitle("Activist, baseline") ytitle("") 
	graph save  "$figures/B1_`var'_2.gph", replace
	twoway (histogram var3,  percent bin(10)) ,xtitle("Activist, w. control") ytitle("") 
	graph save  "$figures/B1_`var'_3.gph", replace

}	



local var  = "LaborForce_Participation"
cap drop var1-var7
{
svmat SENS_`var', names(var)

	reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var2 = var2/_b[School_Dummy]
	
	reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	replace var3 = var3/_b[School_Dummy]
	
	twoway (histogram var2,  percent bin(10)) ,xtitle("LFP, baseline") ytitle("") 
	graph save  "$figures/B1_`var'_2.gph", replace
	twoway (histogram var3,  percent bin(10)) ,xtitle("LFP, w. control") ytitle("") 
	graph save  "$figures/B1_`var'_3.gph", replace

}	


local var  = "Connections"
cap drop var1-var7
{
svmat SENS_`var', names(var)

	reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
	replace var2 = var2/_b[School_Dummy]
	
	reghdfe `var'_D School_Dummy ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	replace var3 = var3/_b[School_Dummy]
	
	twoway (histogram var2,  percent bin(10)) ,xtitle("Networks, baseline") ytitle("") 
	graph save  "$figures/B1_`var'_2.gph", replace
	twoway (histogram var3,  percent bin(10)) ,xtitle("Networks, w. control") ytitle("") 
	graph save  "$figures/B1_`var'_3.gph", replace

}	


*** combine

graph combine 	 "$figures/B1_Writer_2.gph"  "$figures/B1_Activist_2.gph"  "$figures/B1_LaborForce_Participation_2.gph"  "$figures/B1_Connections_2.gph" ///
				 "$figures/B1_Writer_3.gph"   "$figures/B1_Activist_3.gph"  "$figures/B1_LaborForce_Participation_3.gph"  "$figures/B1_Connections_3.gph"  ///
					, rows(2) cols(4) xcommon ycommon
	
graph export "$figures/B1b_Sensitivity_Panel.png", replace width(1000)



********************************************
***	Cross Section Sensitivity
********************************************

use "$data/DNB_CrossSection.dta", clear

levelsof MR_2 if Schools!=0, local(list)
unique MR_2 if Schools!=0
local row `r(unique)'


foreach var of varlist Zeno	LB WRO_Allgemein MP_Weimar {
		    
	mat SENS_`var' = J(`row',5,.)
	local n = 1
	
	qui foreach t of local list {
    preserve
		drop if MR_2==`t'
		
		
		 	mat SENS_`var'[`n',1] = `n'
			reghdfe `var' Schools  if Century==18.5 /// 
					, noabsorb cl(town_id)	
			mat SENS_`var'[`n',2] = _b[Schools]			
				
			reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
			mat SENS_`var'[`n',3] = _b[Schools]			
					
			
					
			reghdfe lnNo`var' Schools  if Century==18.5 /// 
					, noabsorb cl(town_id)	
			mat SENS_`var'[`n',4] = _b[Schools]			
							
			reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	

			mat SENS_`var'[`n',5] = _b[Schools]			
					
	restore 
	local ++n
			

	}
	mat list SENS_`var'
}



local var  = "Zeno"
cap drop var1-var5
{
svmat SENS_`var', names(var)

	reghdfe `var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var2 = var2/_b[Schools]
	
	reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var3 = var3/_b[Schools]
	
	reghdfe lnNo`var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var4 = var4/_b[Schools]
	
	reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var5 = var5/_b[Schools]
	
		twoway (histogram var2,  percent bin(10)) ,xtitle("Encyclopedia, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_2.gph", replace
		twoway (histogram var3,  percent bin(10)) ,xtitle("Encyclopedia, w. control") ytitle("") 
		graph save  "$figures/B2_`var'_3.gph", replace
		twoway (histogram var4,  percent bin(10)) ,xtitle("log Encyclopedia, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_4.gph", replace
		twoway (histogram var5,  percent bin(10)) ,xtitle("log Encyclopedia, w. controls") ytitle("") 
		graph save  "$figures/B2_`var'_5.gph", replace
}	


local var  = "LB"
cap drop var1-var5
{
svmat SENS_`var', names(var)

	reghdfe `var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var2 = var2/_b[Schools]
	
	reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var3 = var3/_b[Schools]
	
	reghdfe lnNo`var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var4 = var4/_b[Schools]
	
	reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var5 = var5/_b[Schools]
	
		twoway (histogram var2,  percent bin(10)) ,xtitle("Leserbriefe, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_2.gph", replace
		twoway (histogram var3,  percent bin(10)) ,xtitle("Leserbriefe, w. control") ytitle("") 
		graph save  "$figures/B2_`var'_3.gph", replace
		twoway (histogram var4,  percent bin(10)) ,xtitle("log Leserbriefe, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_4.gph", replace
		twoway (histogram var5,  percent bin(10)) ,xtitle("log Leserbriefe, w. controls") ytitle("") 
		graph save  "$figures/B2_`var'_5.gph", replace
}	

local var  = "WRO_Allgemein"
cap drop var1-var5
{
svmat SENS_`var', names(var)

	reghdfe `var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var2 = var2/_b[Schools]
	
	reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var3 = var3/_b[Schools]
	
	reghdfe lnNo`var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var4 = var4/_b[Schools]
	
	reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var5 = var5/_b[Schools]
	
		twoway (histogram var2,  percent bin(10)) ,xtitle("Women's rights org., baseline") ytitle("") 
		graph save  "$figures/B2_`var'_2.gph", replace
		twoway (histogram var3,  percent bin(10)) ,xtitle("Women's rights org., w. control") ytitle("") 
		graph save  "$figures/B2_`var'_3.gph", replace
		twoway (histogram var4,  percent bin(10)) ,xtitle("log Women's rights org., baseline") ytitle("") 
		graph save  "$figures/B2_`var'_4.gph", replace
		twoway (histogram var5,  percent bin(10)) ,xtitle("log Women's rights org., w. controls") ytitle("") 
		graph save  "$figures/B2_`var'_5.gph", replace
}	

local var  = "MP_Weimar"
cap drop var1-var5
{
svmat SENS_`var', names(var)

	reghdfe `var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var2 = var2/_b[Schools]
	
	reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var3 = var3/_b[Schools]
	
	reghdfe lnNo`var' Schools  if Century==18.5 /// 
			, noabsorb cl(town_id)	
	replace var4 = var4/_b[Schools]
	
	reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5 &abs(Dist_Boundary)<35 /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
	replace var5 = var5/_b[Schools]
	
		twoway (histogram var2,  percent bin(10)) ,xtitle("MP Weimar, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_2.gph", replace
		twoway (histogram var3,  percent bin(10)) ,xtitle("MP Weimar, w. control") ytitle("") 
		graph save  "$figures/B2_`var'_3.gph", replace
		twoway (histogram var4,  percent bin(10)) ,xtitle("log MP Weimar, baseline") ytitle("") 
		graph save  "$figures/B2_`var'_4.gph", replace
		twoway (histogram var5,  percent bin(10)) ,xtitle("log MP Weimar, w. controls") ytitle("") 
		graph save  "$figures/B2_`var'_5.gph", replace
}	


graph combine 	 "$figures/B2_Zeno_2.gph"  "$figures/B2_Zeno_3.gph"  "$figures/B2_Zeno_4.gph"  "$figures/B2_Zeno_5.gph" ///
				"$figures/B2_LB_2.gph"  "$figures/B2_LB_3.gph"  "$figures/B2_LB_4.gph"  "$figures/B2_LB_5.gph" ///
				 "$figures/B2_WRO_Allgemein_2.gph"  "$figures/B2_WRO_Allgemein_3.gph"  "$figures/B2_WRO_Allgemein_4.gph"  "$figures/B2_WRO_Allgemein_5.gph" ///
				  "$figures/B2_MP_Weimar_2.gph"  "$figures/B2_MP_Weimar_3.gph"  "$figures/B2_MP_Weimar_4.gph"  "$figures/B2_MP_Weimar_5.gph" ///
				, rows(5) cols(4) xcommon ycommon iscale(*0.8)
				
graph save "$figures/B2_Sensitivity_Cross_Section.gph", replace
graph export "$figures/B2_Sensitivity_Cross_Section.png", replace width(1000)		



********************************************************************************
* Construction Activity
********************************************************************************

use "$data/DNB_Panel.dta", clear
sort town_id Century

* Growth is defined as (building!=1&building!=2&building!=3&building!=10&building!=11&building!=12)
cap drop Growth_D lnGrowth
cap drop Const_D lnConst
gen Growth_D = (Growth>0)
gen lnGrowth = log(Growth+1)
gen Const_D = (Construction>0&Construction!=.)
gen lnConst = log(Construction+1)
 
foreach dvar of varlist School_Dummy {


	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	cap drop Window
	gen Treat = 0 if `dvar'==1&`dvar'[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	gen Window = .
	replace Window = 1 if Lag>=-4&Lag<2

	

	eststo clear	
	qui foreach var of varlist Const_D Growth_D Construction Growth lnConst lnGrowth {


				
		eststo: reghdfe `var' `dvar' ///
			if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
				OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century)  cl(town_id) 

			

		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"	

			su `var' if Male_School==0&e(sample)&Post_30yr==1
			estadd scalar MEAN = `r(mean)'	

		}

		

		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats( econ rel  ///
		r2_a N , label("City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Adj. R2" "Observations" "F-Test") fmt(a a a   %9.3f %9.0fc )) ///
		coeflabels (School "Finishing school\(\_{it}\)"  SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post")
	
	// for export	
	esttab using "$tables/B2_Construction.tex" ///
			, replace booktabs fragment nomtitles ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy   "Finishing school\(\_{it}\)"   Male_School "Male school\(\_{it}\)"  Uni "University\(\_{it}\)"  End_WT "End of Witch Trial\(\_{it}\)"  ) ///
			nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _) 	
						
}


*
	
// bring panels together: Construction
		#delimit ;
		esttab using "$tables/B2_Panel.tex", replace booktabs
			cells(none) nonote noobs 			mtitles("Any" "Growth" "Any" "Growth" "Any" "Growth") ///
						mgroups(" \(\mathbb{I}[>0]\)}"  " \emph{Number}}"  "\emph{log}}"  , pattern(1 0 1 0 1 0 ) prefix("\multicolumn{@span}{c}{")  span ) ///
			prefoot(			
			\panelinput{"Tables/B2_Construction"} \midrule )
			substitute(\_ _)	
		stats(econ rel education ///
		, label( "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE"  "Educational covariates \(\times\) period FE" ///
		) fmt(a a )) ///
		coeflabels (School_Dummy   "Finishing school\(\_{it}\)"  Male_School "Boy school\(\_{it}\)"  Uni "University\(\_{it}\)"  End_WT "End of Witch Trial\(\_{it}\)" )
		;
#delimit cr	


********************************************************************************
* Controlling flexibly for construction
********************************************************************************

use "$data/DNB_Panel.dta", clear
sort town_id Century
* School Construction
gen Const_D = (Construction>0&Construction!=.)
gen lnConst = log(Construction+1)	

cap drop LaborForce_Participation LaborForce_Participation_D Share_LaborForce_Participation lnLaborForce_Participation
egen LaborForce_Participation = rowtotal(Occupations Medicine Teacher Academic Writer )
gen LaborForce_Participation_D = (LaborForce_Participation>0) if LaborForce_Participation!=.
gen Share_LaborForce_Participation = (LaborForce_Participation)/(LaborForce_Participation+M_Occupation+1)
gen lnLaborForce_Participation = log(LaborForce_Participation+1)

foreach var of varlist  NonRoyalReligion  {

eststo clear
qui {
	
	
	
	* FE DUMMY
	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Const_1650##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local const_1650 "Yes"
		estadd local const ""

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Construction##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local const_1650 ""
		estadd local const "Yes"	

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	
		* FE Log
	

		
	eststo: reghdfe ln`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Const_1650##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local const_1650 "Yes"
		estadd local const ""

		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
			
	eststo: reghdfe ln`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Construction##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"	
		estadd local psmatch "Yes"
		estadd local const_1650 ""
		estadd local const "Yes"

		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
						
			
			
* FE Share

	
		
	eststo: reghdfe Share_`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Const_1650##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local const_1650 "Yes"
		estadd local const ""
		
		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
	
	
	eststo: reghdfe Share_`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century Construction##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local const_1650 ""
		estadd local const "Yes"		

		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
	 
}
	// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education ///
		r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Adj. R2" "Observations" "Mean") fmt(a a a a  %9.3f %9.0fc %9.3f)) ///
		coeflabels (School "Finishing school\(\_it\)" )
	
		
	
// for export	
	esttab using "$tables/B3_`var'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			stats(MEAN, label("Mean, untreated") fmt(%9.3f))	///
			substitute(\_ _) 
				
	
}
// bring panels together
		#delimit ;
		esttab using "$tables/B3_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("\$\mathbb{I}[Women>0]\$" "log Women" "Share Women", pattern(1 0 1 0 1 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\panelinput{"Tables/B3_NonRoyalReligion"} 
			\midrule  )
			substitute(\_ _)	
		stats(localitytrend econ rel education psmatch const_1650 const ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" "Construction in 1650 \(\times\) period FE" ///
		"Construction in every period \(\times\) period FE" "Observations" ) fmt(a a a a a a a %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr
		




********************************************************************************
* Controlling flexibly for population
********************************************************************************

use "$data/DNB_Panel.dta", clear
sort town_id Century
* School Construction

gen lnInh_1600 = log(inhabitants_1600+1)
gen lnInh = log(inhabitants+1)


foreach var of varlist  NonRoyalReligion  {

eststo clear
qui {
	
	
	
	* FE DUMMY
	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop "Yes"
		

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnInh_1600##Century ///
		OldSchool##Century Uni_1650#Century  ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop ""
		estadd local inh "Yes"	

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	
		* FE Log
	

		
	eststo: reghdfe ln`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop "Yes"

		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
			
	eststo: reghdfe ln`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnInh_1600##Century ///
		OldSchool##Century Uni_1650#Century  ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop ""
		estadd local inh "Yes"	

		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
						
			
			
* FE Share

	
		
	eststo: reghdfe Share_`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop "Yes"
		
		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
	
	
	eststo: reghdfe Share_`var' School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnInh_1600##Century ///
		OldSchool##Century Uni_1650#Century  ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		estadd local pop ""
		estadd local inh "Yes"		

		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
	 
}
	// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education psmatch pop inh  ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" "log Bairoch population in 1600 \(\times\) period FE" ///
		"log Buringh population in 1600 \(\times\) period FE" "Observations" ) fmt(a a a a a a a %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
	
		
	
// for export	
	esttab using "$tables/B4_`var'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			stats(MEAN, label("Mean, untreated") fmt(%9.3f))	///
			substitute(\_ _) 
				
	
}
// bring panels together
		#delimit ;
		esttab using "$tables/B4_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("\$\mathbb{I}[Women>0]\$" "log Women" "Share Women", pattern(1 0 1 0 1 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\panelinput{"Tables/B4_NonRoyalReligion"} 
			\midrule  )
			substitute(\_ _)	
		stats(localitytrend econ rel education psmatch pop inh  ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" "log Bairoch population in 1600 \(\times\) period FE" ///
		"log Buringh population in 1600 \(\times\) period FE" "Observations" ) fmt(a a a a a a a %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr
		

