use "$data/DNB_Panel.dta", clear

cap drop LaborForce_Participation LaborForce_Participation_D Share_LaborForce_Participation lnLaborForce_Participation
egen LaborForce_Participation = rowtotal(Occupations Medicine Teacher Academic Writer )
gen LaborForce_Participation_D = (LaborForce_Participation>0) if LaborForce_Participation!=.
gen Share_LaborForce_Participation = (LaborForce_Participation)/(LaborForce_Participation+M_Occupation+1)
gen lnLaborForce_Participation = log(LaborForce_Participation+1)


******************************************************
* Population:
******************************************************

su Pop_Panel 

foreach var of varlist Pop_Panel  { 
preserve
	
	*** Preparation -- variable definition

	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}
	
	// Non-Royals
	eststo clear
	eststo: reghdfe `var' ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		, a(town_id CENT ) cl(town_id)
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p1 = `r(p)'
		
	mat LL = J(12,10,.)
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=_b[T_LL_`n1']
			mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		local n = `n'+1
	}
	
	
	// Royals
	eststo: reghdfe `var' ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p2 = `r(p)'
	
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',5]=_b[T_LL_`n1']
			mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		local n = `n'+1
	}
	
	

	mat list LL
	cap drop LL1-LL10
	svmat LL	

	gen LL_1 = 0
	replace LL_1 = LL1-0.025 if LL1!=0
	gen LL_2 = 0 
	replace LL_2 = LL1+0.025 if LL1 !=0
	
	local pp1 : di %4.3f `p1'
	local pp2 : di %4.3f `p2'
	
		twoway (line LL2 LL_1) (rcap LL3 LL4 LL_1) ///
	(line LL5 LL_2, lcolor(gs8) lpattern(longdash_dot)) (rcap LL6 LL7 LL_2, lcolor(gs8) lpattern(longdash_dot)) ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(off ) note("p-value leads = lags: `pp1' without covariates and `pp2' with covariates") ///
	xtitle(Century lags)   
	

	graph export "$figures/D1_Figure_`var'.png", replace width(1000)

restore	
}


	
******************************************************
* Enlightenment:
******************************************************	
	
cap drop h	
cap drop School_Open
gen h = School_Century

replace h = Century if h!=0
replace h = . if h==0

bysort town_id: egen School_Open=min(h)
replace School_Open = 0 if School_Open==.	
tab School_Open if Century==18.5
su School_Open if School_Open!=0, det
local refyear = `r(p50)'
*** In the year prior to the finishing school opening:
cap drop Pre_School
gen Pre_School = School_Open   -0.5

cap drop ControlSample
gen ControlSample 		= 1 if Schools==0&(Century==`refyear')

eststo clear
qui foreach var of varlist NonRoyalReligion_D NoEnlightenmentJournal NoEnlightenmentArticles {
eststo: reghdfe `var' GirlSchool /// 
		lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
		if (Pre_School==Century|ControlSample==1), ///
		a(Hanse bishop Jewish Progrom Battle OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local year "Yes"
			estadd scalar bw 35
			su `var' if e(sample)
			estadd scalar MEAN = `r(mean)'	
}
esttab, keep(GirlSchool) star(* 0.1 ** 0.05 *** 0.01) /// 
	stats(econ rel education year  ///
	N bw MEAN, label( "City Covariates"	"Religious covariates" "Educational covariates" "Period fixed effects" ///
	"Observations" "Bandwidth" "Mean dep. var.") fmt(a a a a %9.0fc %9.0fc %9.3f)) ///
	coeflabels (Schools "Finishing schools")


*** In the year of finishing school opening:
cap drop Pre_School
gen Pre_School = School_Open  

cap drop ControlSample
gen ControlSample 		= 1 if Schools==0&(Century==`refyear')

qui foreach var of varlist NonRoyalReligion_D NoEnlightenmentJournal  NoEnlightenmentArticles  {
eststo: reghdfe `var' GirlSchool /// 
		lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
		if (Pre_School==Century|ControlSample==1) , ///
		a(Hanse bishop Jewish Progrom Battle OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local year "Yes"
			
			su `var' if e(sample)
			estadd scalar MEAN = `r(mean)'		
			
}
esttab, keep(GirlSchool) star(* 0.1 ** 0.05 *** 0.01) /// 
	stats(econ rel education year  ///
	N bw MEAN, label( "City Covariates"	"Religious covariates" "Educational covariates" "Period fixed effects" ///
	"Observations" "Bandwidth" "Mean dep. var.") fmt(a a a a %9.0fc %9.0fc %9.3f)) ///
	coeflabels (Schools "Finishing schools")
	
// for export	
	esttab using "$tables/D1_Enlightenment.tex" ///
			, replace booktabs fragment ///
			keep(GirlSchool) ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (GirlSchool "Finishing school") ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _) 
	

// bring panels together
		#delimit ;
		esttab using "$tables/D1_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("Period prior to finishing school establishment" "Period of finishing school establishment", pattern(1 0 0 1 0 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Non-Noble Seculars}} \\ 
			\panelinput{"Tables/D1_Enlightenment"} 
			 &\multicolumn{1}{c}{\rule{2cm}{0pt}} &\multicolumn{1}{c}{\rule{2cm}{0pt}} &\multicolumn{1}{c}{\rule{2cm}{0pt}} &\multicolumn{1}{c}{\rule{2cm}{0pt}} &\multicolumn{1}{c}{\rule{2cm}{0pt}} &\multicolumn{1}{c}{\rule{2cm}{0pt}} \\
			 \midrule )
			substitute(\_ _)	
			stats(econ rel education year  ///
				N MEAN, label( "City Covariates"	"Religious covariates" "Educational covariates" "Period fixed effects" ///
				"Observations"  "Mean dep. var.") fmt(a a a a %9.0fc %9.0fc %9.3f)) ///
				coeflabels (Schools "Finishing schools") ///
			
		;
		#delimit cr		

*****************
* Control for enlightenment books
*****************		


foreach var of varlist  NonRoyalReligion  {

eststo clear
qui {
	
	
	
	* FE DUMMY

		
	eststo: reghdfe Activist_D School_Dummy ///
		,a(NoEnlightenmentJournal Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"
		estadd local Enlightenment "Journals"

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		

		
	eststo: reghdfe `var'_D School_Dummy ///
		,a( NoEnlightenmentArticles Century town_id##c.Century  Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"
		estadd local Enlightenment "Articles"

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'					
		
	
		* FE Log
	
		
	eststo: reghdfe ln`var' School_Dummy ///
		,a(NoEnlightenmentJournal Century town_id##c.Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century  Match_ID##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"	
		estadd local Enlightenment "Journals"

		su `var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	eststo: reghdfe ln`var' School_Dummy ///
		,a( NoEnlightenmentArticles Century town_id##c.Century  Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"	
		estadd local Enlightenment "Articles"

		su `var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
			
* FE Share

	eststo: reghdfe Share_`var' School_Dummy ///
		,a(NoEnlightenmentJournal Century town_id##c.Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century  Match_ID##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"
		estadd local Enlightenment "Journals"

		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'					
		
	eststo: reghdfe Share_`var' School_Dummy ///
		,a( NoEnlightenmentArticles Century town_id##c.Century  Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local psmatch "Yes"
		estadd local education "Yes"
		estadd local Enlightenment "Articles"

		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
	
	 
}
	// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education Enlightenment ///
		r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Enlightenment Control" ///
		"Adj. R2" "Observations" "Mean") fmt(a a a a a %9.3f %9.0fc %9.3f)) ///
		coeflabels (School "Finishing school\(\_it\)" )
	// for export	

	
// for export	
	esttab using "$tables/D2_`var'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _) ///
			stats(MEAN, label("Mean, untreated") fmt(%9.3f))	
	
}
// bring panels together
		#delimit ;
		esttab using "$tables/D2_panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("\$\mathbb{I}[Women>0]\$" "log Women" "Share Women", pattern(1 0 1 0 1 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Non-Noble Seculars}} \\ 
			\panelinput{"Tables/D2_NonRoyalReligion"} 
			\midrule )
			substitute(\_ _)	
		stats(localitytrend econ rel education Enlightenment psmatch ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE"  "\# Enlightenment:" ///
		"Matching on 1600 covariates"  "Observations" ) fmt(a a a a a a %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr					

		

********************************************************************************
* Schools predicting Enlightenment in the cross section
********************************************************************************


use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Table 6: Long-term impact of finishing School on the women’s rights movement and political representation
//------------------------------------------------------------------------


local m =10

xi i.Hanse i.bishop i.Jewish i.Progrom i.Battle  i.OldSchool i.Uni_1650 i.MR_2 i.Catholic

cap drop _ID

global full2 lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650  _I* 

*****************
* Do Schools Predict Enlightenment Journals?
*****************

foreach c of numlist 18 {

cap drop help 
cap drop lnNoEJ NoEJ EJ
gen help = NoEnlightenmentJournal if Century==`c'
bysort town_id: egen NoEJ = max(help)
gen lnNoEJ = log(NoEJ+1)
gen EJ = (NoEJ>0)

cap drop help 
cap drop lnNoEA NoEA EA
gen help = NoEnlightenmentArticles if Century==`c'
bysort town_id: egen NoEA = max(help)
gen lnNoEA = log(NoEA+1)
gen EA = (NoEA>0)

foreach var of varlist 	EJ EA {
eststo clear
qui{

	eststo: reghdfe `var' School  if Century==`c' /// 
			, noabsorb cl(town_id)	
					
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'				
			estadd local econ ""
			estadd local rel ""
			estadd local education ""
			
			local b = _b[School]
	


			
		*** OSTER ***
		qui reg `var' School if Century==`c' , cl(town_id)
			local br = _b[School]
			local rr = e(r2)
		qui reg `var' School $full2 if Century==`c' &abs(Dist_Boundary)<`m', cl(town_id)
			local bf = _b[School]
			local rf = e(r2)
		local rmax = 1.3*`rf'
		di `bf'-(`br'-`bf')*((`rmax'-`rf')/(`rf'-`rr'))
		local oster = `bf'-(`br'-`bf')*((`rmax'-`rf')/(`rf'-`rr'))
		*psacalci `br' `rr' `bf' `rf' `br' , rmax(`rmax') delta(1) beta(0)
		*	local oster = `r(output)'	
		
		*** IV estimate:
		ivreghdfe `var' (School=Monastries_1300) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==`c'&abs(Dist_Boundary)<`m' /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
			local iv = _b[School]
		
			eststo: reghdfe `var' School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==`c' &abs(Dist_Boundary)<`m' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'			
			estadd scalar Oster = `oster'
			estadd scalar IV = `iv'
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = `m'
		
	eststo: reghdfe lnNo`var' School  if Century==`c' /// 
			, noabsorb cl(town_id)	
					
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'				
			estadd local econ ""
			estadd local rel ""
			estadd local education ""
			
	local b = _b[School]
		
			
			*** OSTER ***
		qui reg lnNo`var' School if Century==`c' , cl(town_id)
			local br = _b[School]
			local rr = e(r2)
		qui reg lnNo`var' School $full2 if Century==`c' &abs(Dist_Boundary)<`m', cl(town_id)
			local bf = _b[School]
			local rf = e(r2)
		local rmax = 1.3*`rf'
		di `bf'-(`br'-`bf')*((`rmax'-`rf')/(`rf'-`rr'))
		local oster = `bf'-(`br'-`bf')*((`rmax'-`rf')/(`rf'-`rr'))
		*psacalci `br' `rr' `bf' `rf' `br' , rmax(`rmax') delta(1) beta(0)
		*	local oster = `r(output)'	
		
		*** IV:
		ivreghdfe lnNo`var' (School=Monastries_1300) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==`c'&abs(Dist_Boundary)<`m' /// 
					, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
			local iv = _b[School]
			
			eststo: reghdfe lnNo`var' School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==`c' &abs(Dist_Boundary)<`m' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
						
			estadd scalar Oster = `oster'
			estadd scalar IV = `iv'					
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = `m'
	
			
			
		

}
	esttab, keep(School) se star(* 0.1 ** 0.05 *** 0.01) stats(N r2 MEAN Oster IV, fmt( %9.0fc %9.3f %9.3f %9.3f)) 
		
	
	

	// for export	
	esttab using "$tables/D3_`var'.tex" ///
			, keep(School ) replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School "Finishing School" ) ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _) ///
			stats(r2 MEAN Oster IV, label("R-squared" "Mean, untreated" "Bias-Adjusted \(\beta\)" "IV estimate using Monasteries in 1300") fmt(%9.3f %9.3f %9.3f %9.3f))	
			
					
	
}
}
// bring panels together
		#delimit ;
		esttab using "$tables/D3_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("\$\mathbb{I}[>0]\$" "log Number" , pattern(1 0 1 0 ) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Enlightenment Journals }} \\ 
			\panelinput{"Tables/D3_EJ.tex"} 
			\midrule )
			substitute(\_ _)	
		stats(econ rel education ///
		N bw , label( "City Covariates"	"Religious covariates" "Educational covariates " ///
		"Observations" "Bandwidth") fmt(a a a %9.0fc %9.0fc %9.3f)) ///
		coeflabels (School "Finishing School")
		;
		#delimit cr


*****************
* Economic Demands for educated workers
*****************		
		
cap drop h	
cap drop School_Open
gen h = School_Century

replace h = Century if h!=0
replace h = . if h==0

bysort town_id: egen School_Open=min(h)
replace School_Open = 0 if School_Open==.	
tab School_Open
	
	
foreach var of varlist  NonRoyalReligion {

eststo clear
qui {
	
	
	
	* FE DUMMY
	

eststo: reghdfe `var'_D School_Dummy ///
			if School_Open==0|School_Open<18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"

	eststo: reghdfe `var'_D School_Dummy ///
			if School_Open==0|School_Open>=18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 	
		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"	
		* FE Log

		
	eststo: reghdfe ln`var' School_Dummy ///
			if School_Open==0|School_Open<18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id)  

		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'			
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"	

	eststo: reghdfe ln`var' School_Dummy ///
			if School_Open==0|School_Open>=18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id)		
		su ln`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'			
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"			
		
* FE Share

		
		
	eststo: reghdfe Share_`var' School_Dummy ///
			if School_Open==0|School_Open<18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"

	eststo: reghdfe Share_`var' School_Dummy ///
			if School_Open==0|School_Open>=18 ///
			,a(Century town_id##c.Century ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 			
		su Share_`var' if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'			
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"	
	 
}
	// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education ///
		r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Adj. R2" "Observations" "Mean") fmt(a a a a  %9.3f %9.0fc %9.3f)) ///
		coeflabels (School "Finishing school\(\_it\)" )
	// for export	
	esttab using "$tables/D4_`var'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			stats(MEAN, label("Mean, untreated") fmt(%9.3f))	///
			substitute(\_ _) 
				
	
}
// bring panels together
		#delimit ;
		esttab using "$tables/D4_panel.tex", replace booktabs
			cells(none) nonote noobs  ///
			mtitles("Early" "Late" "Early" "Late" "Early" "Late") ///
			mgroups("\$\mathbb{I}[Women>0]\$" "log Women" "Share Women", pattern(1 0 1 0 1 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Non-Noble Seculars}} \\ 
			\panelinput{"Tables/D4_NonRoyalReligion"} 
			 \midrule )
			substitute(\_ _)	
		stats(localitytrend econ rel education ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Observations" ) fmt(a a a a  %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr

	
		