
use "$data/DNB_Panel.dta", clear
cap drop h	
cap drop School_Open
gen h = School_Century

replace h = Century if h!=0
replace h = . if h==0

bysort town_id: egen School_Open=min(h)
replace School_Open = 0 if School_Open==.	
replace School_Open = School_Open*100
tab School_Open

*** Get baseline ATT:
	*** Preparation -- variable definition
preserve
	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}
	
			
	// Non-Royals
	eststo clear
	eststo: reghdfe NonRoyalReligion_D ///
		School_Dummy ///
		if Window!=. ///
		, a(town_id CENT ) cl(town_id)
restore		


sort town_id CENT
cap drop Sample
gen Sample = 1 if Schools==0
replace Sample = 1 if School_Dummy==1&School_Dummy[_n-1]==0
replace Sample = 1 if School_Dummy==0&School_Dummy[_n+1]==1
reghdfe NonRoyalReligion_D School_Dummy ,a(Century town_id) cl(town_id)
reghdfe NonRoyalReligion_D School_Dummy if Sample==1,a(Century town_id) cl(town_id)
qui did_multiplegt NonRoyalReligion_D town_id CENT School_Dummy, cluster(town_id) 
ereturn list

* We are comparing the switchers ***/	
**** Chaisement:
*** Other code 
did_multiplegt NonRoyalReligion_D town_id CENT School_Dummy, cluster(town_id) dynamic(5) average_effect robust_dynamic covariances breps(100)
di e(effect_average) 
di e(se_effect_average)


qui twowayfeweights NonRoyalReligion_D town_id CENT School_Dummy,  type(feS)
ereturn list


//------------------------------------------------------------------------
*** Goodman bacon decomposition
//------------------------------------------------------------------------

sort town_id CENT
xtset town_id CENT
xtreg  NonRoyalReligion_D School_Dummy i.CENT , fe robust
keep if e(sample)

foreach var of varlist NonRoyalReligion_D lnNonRoyalReligion Share_NonRoyalReligion {
	cap drop Bacon*
cap label drop Bacon_gp
cap label drop Bacon_cgroup
	bacondecomp `var' School_Dummy , stub(Bacon_)  cl(town_id) 
}



/*
Computing decomposition across 6 timing groups
including a never-treated group
------------------------------------------------------------------------------
NonRoyalRe~D |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
School_Dummy |   .2659431   .0282795     9.40   0.000     .2105164    .3213698
------------------------------------------------------------------------------

Bacon Decomposition

+---------------------------------------------------+
|                      |         Beta   TotalWeight |
|----------------------+----------------------------|
|        Timing_groups |   .092968813   .0849173328 |
|       Never_v_timing |  .2819946915   .9150826672 |
+---------------------------------------------------+
Computing decomposition across 6 timing groups
including a never-treated group
------------------------------------------------------------------------------
lnNonRoyal~n |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
School_Dummy |   .3978519   .0558695     7.12   0.000     .2883496    .5073542
------------------------------------------------------------------------------

Bacon Decomposition

+---------------------------------------------------+
|                      |         Beta   TotalWeight |
|----------------------+----------------------------|
|        Timing_groups |   .108803565   .0849173328 |
|       Never_v_timing |  .4246748274   .9150826672 |
+---------------------------------------------------+
Computing decomposition across 6 timing groups
including a never-treated group
------------------------------------------------------------------------------
Share_NonR~n |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
School_Dummy |    .020767   .0042906     4.84   0.000     .0123576    .0291765
------------------------------------------------------------------------------

Bacon Decomposition

+---------------------------------------------------+
|                      |         Beta   TotalWeight |
|----------------------+----------------------------|
|        Timing_groups |   .014474902   .0849173328 |
|       Never_v_timing |  .0213509424   .9150826672 |
+---------------------------------------------------+


*/

cap drop Bacon*
cap label drop Bacon_gp
cap label drop Bacon_cgroup
bacondecomp NonRoyalReligion_D School_Dummy , stub(Bacon_)  cl(town_id) 
graph export "$figures/F1_GoodmanBacon.png", replace as(png) width(2000)

did_multiplegt NonRoyalReligion_D town_id CENT School_Dummy, cluster(town_id)  breps(100)  robust_dynamic
di e(effect_0) 
di e(se_effect_0)
did_multiplegt lnNonRoyalReligion town_id CENT School_Dummy, cluster(town_id)  breps(100)  robust_dynamic
di e(effect_0) 
di e(se_effect_0)
did_multiplegt Share_NonRoyalReligion town_id CENT School_Dummy, cluster(town_id)  breps(100)  robust_dynamic
di e(effect_0) 
di e(se_effect_0)


/*******************************************************************************
Callaway Sant Anna 2020
*/******************************************************************************

use "$data/DNB_Panel.dta", clear

cap drop h	
cap drop School_Open
gen h = School_Century

replace h = Century if h!=0
replace h = . if h==0

bysort town_id: egen School_Open=min(h)
replace School_Open = 0 if School_Open==.	
replace School_Open = School_Open*100
tab School_Open


csdid NonRoyalReligion_D, ivar(town_id) time(CENT) gvar(School_Open)  agg(group)
/*
csdid_plot	//PRoduced an '}' error
graph export "$figures/F2a_CSA_Group_NonRoyalReligion_D.png", replace width(2000)
*/

csdid NonRoyalReligion_D, ivar(town_id) time(CENT) gvar(School_Open)  agg(event)
csdid_plot
graph export "$figures/F2b_CSA_Event_NonRoyalReligion_D.png", replace width(2000)



//------------------------------------------------------------------------
*** Including all cities and covariates
//------------------------------------------------------------------------	


use "$data/DNB_Panel.dta", clear


*************
* Main Figure
*************

{
preserve
	
	*** Preparation -- variable definition

	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	replace Lag = -4 if Lag<-4|Lag==.
	replace Lag = 1.5 if Lag>1.5
	
	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*

	
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}

			
// Non-Royals
eststo clear
eststo: reghdfe NonRoyalReligion_D ///
	T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
	T_LL_7	///
	T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
	, a(town_id CENT ) cl(town_id)
	test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
	local p1 = `r(p)'
	
mat LL = J(12,10,.)
local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',1]=`c'
		mat LL[`n1',2]=0
		mat LL[`n1',3]=0
		mat LL[`n1',4]=0
	}
	if  `c'!=-4 {
		mat LL[`n1',1]=`c'
		mat LL[`n1',2]=_b[T_LL_`n1']
		mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
		mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
	}
	
	local n = `n'+1
}


// Royals
eststo: reghdfe NonRoyalReligion_D ///
	T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
	T_LL_7	///
	T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
	,a(Century town_id ///
	Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
	Battle##Century c.lnDW##Century ///
	c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
	c.Winter_1650##Century ///
	c.lnPop##Century ///
	OldSchool##Century Uni_1650#Century ///
	MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
	test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
	local p2 = `r(p)'

local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',5]=0
		mat LL[`n1',6]=0
		mat LL[`n1',7]=0
	}
	if  `c'!=-4 {
		mat LL[`n1',5]=_b[T_LL_`n1']
		mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
		mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
	}

	local n = `n'+1
}



mat list LL
cap drop LL1-LL10
svmat LL	


local pp1 : di %4.3f `p1'
local pp2 : di %4.3f `p2'

twoway (line LL5 LL1) (rcap LL6 LL7 LL1)  ///
, yline(0)  xlabel(-3.5(0.5)1.5) /// 
legend(off ) note("p-value leads = lags: `pp2' with covariates") ///
xtitle(Century lags)   
	
	graph export "$figures/F3a_AllCity.png", replace width(2000)
	

restore	
}

*************
* Main Figure: Log number
*************
{
preserve
	
	*** Preparation -- variable definition

	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	replace Lag = -4 if Lag<-4|Lag==.
	replace Lag = 1.5 if Lag>1.5
	
	
	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}

			
	// Non-Royals
	eststo clear
	eststo: reghdfe lnNonRoyalReligion ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_7	///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		, a(town_id CENT ) cl(town_id)
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p1 = `r(p)'
		
	mat LL = J(12,10,.)
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		if  `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=_b[T_LL_`n1']
			mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		
		local n = `n'+1
	}
	
	
	// Royals
	eststo clear
	eststo: reghdfe lnNonRoyalReligion ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_7	///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p2 = `r(p)'
	
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		if  `c'!=-4 {
			mat LL[`n1',5]=_b[T_LL_`n1']
			mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		
		local n = `n'+1
	}
	
	

	mat list LL
	cap drop LL1-LL10
	svmat LL	


	local pp1 : di %4.3f `p1'
	local pp2 : di %4.3f `p2'
	
	twoway (line LL5 LL1) (rcap LL6 LL7 LL1)  ///
		, yline(0)  xlabel(-3.5(0.5)1.5) /// 
		legend(off ) note("p-value leads = lags: `pp2' with covariates") ///
		xtitle(Century lags)  
	

	graph export "$figures/F3a_AllCity_Log.png", replace width(2000)


restore	
}
*************
* Main Figure: Shares
*************
{
preserve
	
	*** Preparation -- variable definition

	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	replace Lag = -4 if Lag<-4|Lag==.
	replace Lag = 1.5 if Lag>1.5

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}

			
	// Non-Royals
	eststo clear
	eststo: reghdfe Share_NonRoyalReligion ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_7 ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		, a(town_id CENT ) cl(town_id)
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p1 = `r(p)'
		di `p1'
		
	mat LL = J(12,10,.)
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		if  `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=_b[T_LL_`n1']
			mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		
		local n = `n'+1
	}
	
	
	// Royals
	eststo clear
	eststo: reghdfe Share_NonRoyalReligion ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_7 ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 +T_LL_7 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p2 = `r(p)'
	
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		if `c'!=-4 {
			mat LL[`n1',5]=_b[T_LL_`n1']
			mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}

		local n = `n'+1
	}
	
	



	mat list LL
	cap drop LL1-LL10
	svmat LL	

	local pp1 : di %4.3f `p1'
	local pp2 : di %4.3f `p2'
	
	twoway (line LL5 LL1) (rcap LL6 LL7 LL1)  ///
		, yline(0)  xlabel(-3.5(0.5)1.5) /// 
		legend(off ) note("p-value leads = lags: `pp2' with covariates") ///
		xtitle(Century lags)  
			
	
	graph export "$figures/F3a_AllCity_Share.png", replace width(2000)


restore	
}		

