use "$data/DNB_CrossSection.dta", clear

********************************************************************************
* Long-term impact of finishing schools on political outcomes - IV estimates using different timings of the Monastry instrument
********************************************************************************

*** Table:
local bw = 10
** IV Tables
foreach var of varlist 	LB Zeno WRO_Allgemein MP_Weimar {
	eststo clear
	qui {

		

		eststo: ivreghdfe `var' (Schools=Monastries_1300) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'		
			estadd scalar M = 1300
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
		eststo: ivreghdfe `var' (Schools=Monastries_1500) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'	
			estadd scalar M = 1500
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
		eststo: ivreghdfe `var' (Schools=Monastries_Remain) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'		
			estadd scalar M = 1648
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
		
			
		eststo: ivreghdfe lnNo`var' (Schools=Monastries_1300) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'				
			estadd scalar BW = `bw'	
			estadd scalar M = 1300
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
		eststo: ivreghdfe lnNo`var' (Schools=Monastries_1500) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'				
			estadd scalar BW = `bw'
			estadd scalar M = 1500
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
		eststo: ivreghdfe lnNo`var' (Schools=Monastries_Remain) lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'				
			estadd scalar BW = `bw'
			estadd scalar M = 1648
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
	}

	esttab, keep(Schools ) se star(* 0.1 ** 0.05 *** 0.01) stats(N MEAN rkf, fmt( %9.0fc %9.3f %9.3f)) 
	
// for export	
	esttab using "$tables/H1_`var'.tex" ///
			, keep(Schools ) replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (Schools "Finishing schools") ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _) ///
			stats(MEAN , label("Mean, untreated" ) fmt(%9.3f %9.3f))	
	
}

// bring panels together
	#delimit ;
	esttab using "$tables/H1_Panel.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
		mgroups("\$\mathbb{I}[>0]\$" "log Number" , pattern(1 0 0 1 0 0 ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(
		\multicolumn{@span}{l}{\emph{Panel A: Encyclopedia of female writers }} \\ 
		\panelinput{"Tables/H1_Zeno"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel B: Leserbriefe, Frauenzeitung, 1849--1852 }} \\ 
		\panelinput{"Tables/H1_LB"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel C: Women's rights organizations}} \\ 
		\panelinput{"Tables/H1_WRO_Allgemein"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel D: Member Parliament, 1919--1933}} \\ 
		\panelinput{"Tables/H1_MP_Weimar"} \midrule )
		substitute(\_ _)	
	stats(econ rel education ///
	N BW M rkf, label( "City Covariates"	"Religious covariates" "Educational covariates " ///
	"Observations" "Bandwidth" "Monastery Year" "F-Stat first stage") fmt(a a a %9.0fc %9.0fc %9.0f %9.3f)) ///
	coeflabels (Schools "Finishing schools")
	;
	#delimit cr						

	
********************************************************************************
*** Table using log years of schools (As we have from 0 - 226 years)
********************************************************************************
cap drop Years_School
cap drop lnYears_School
gen Years_School = 0 if Schools==0
replace Years_School = 1850-YearFirstSchool if YearFirstSchool!=0

gen lnYears_School = log(Years_School+1)

** IV Tables

*** Table:
local bw = 10
** IV Tables
foreach var of varlist 	LB Zeno WRO WRO_Allgemein MP_Weimar {
	eststo clear
	qui {

		local bw = 400	
		eststo: reghdfe `var' Years_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
		local bw = 10	
		eststo: reghdfe `var' Years_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

	
			
		local bw = 400	
		eststo: reghdfe `var' lnYears_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"

		local bw = 10
		eststo: reghdfe `var' lnYears_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su `var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
					
			
			
		local bw = 400	
		eststo: reghdfe lnNo`var' Years_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
		local bw = 10
		eststo: reghdfe lnNo`var' Years_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			
		
			
			
		local bw = 400	
		eststo: reghdfe lnNo`var' lnYears_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"		
			
			
		local bw = 10
		eststo: reghdfe lnNo`var' lnYears_School lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if Century==18.5&abs(Dist_Boundary)<`bw' /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		su No`var' if GirlSchool==0&e(sample)
			estadd scalar MEAN = `r(mean)'	
			estadd scalar BW = `bw'				
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			

			
	}

	esttab, keep(Years_School lnYears_School ) se star(* 0.1 ** 0.05 *** 0.01) stats(N MEAN rkf, fmt( %9.0fc %9.3f %9.3f)) 
	
// for export	
	esttab using "$tables/H2_`var'.tex" ///
			, keep(Years_School lnYears_School ) replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (Years_School "Years since first opening" lnYears_School "log Years since first opening") ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _) ///
			stats(MEAN , label("Mean, untreated" ) fmt(%9.3f %9.3f))	
	
}
//

// bring panels together
		#delimit ;
		esttab using "$tables/H2_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("\$\mathbb{I}[>0]\$" "log Number" , pattern(1 0 0 0 1 0 0 0) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Encyclopedia of female writers }} \\ 
			\panelinput{"Tables/H2_Zeno"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel B: Leserbriefe, Frauenzeitung, 1849--1852 }} \\ 
			\panelinput{"Tables/H2_LB"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel C: Women's rights organizations}} \\ 
			\panelinput{"Tables/H2_WRO_Allgemein"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel D: Member Parliament, 1919--1933}} \\ 
			\panelinput{"Tables/H2_MP_Weimar"}  \midrule )				
			substitute(\_ _)	
		stats(econ rel education ///
		N BW , label( "City Covariates"	"Religious covariates" "Educational covariates " ///
		"Observations" "Bandwidth" ) fmt(a a a %9.0fc %9.0fc %9.0f )) ///
		coeflabels (Schools "Finishing schools")
		;
		#delimit cr	
	
	

******************************************************
*** Nearest Neighbor matching:
******************************************************
use "$data/DNB_CrossSection.dta", clear
cap drop Match*
cap drop obs
gen obs = _n
*** Crate Match variable
teffects psmatch (lnNoWRO) (GirlSchool ///
		lnDW lnDistBoundary  Spring_1650 Summer_1650 Fall_1650 Winter_1650  ///
		lnPop Hanse bishop Jewish Progrom Battle OldSchool Uni_1650 MR_2 Catholic)   /// 
		, vce(robust, nn(2)) caliper(0.5)  gen(Match)

						
predict that , ps
		
tempfile temp
save `temp',replace // save the complete data set

keep if GirlSchool==1 // keep just the treated group
keep Match1 // keep just the match1 variable (the observation numbers of their matches)
bysort Match1: gen weight=_N // count how many times each control observation is a match
by Match1: keep if _n==1 // keep just one row per control observation
ren Match1 obs //rename for merging purposes

merge 1:m obs using `temp' // merge back into the full data
replace weight=1 if GirlSchool // set weight to 1 for treated observations

			
rename Match1 Match

*br town_id obs Match GirlSchool
tab Match, sort
sort Match
levelsof Match, local(list)
cap drop Match_ID
gen Match_ID=.
qui foreach l of local list { 

	replace Match_ID=`l' if (Match==`l'|obs==`l')&Match_ID==.

}


eststo clear
qui eststo: reghdfe lnNoWRO Schools , noabsorb cl(town_id) 
qui eststo: reghdfe lnNoWRO Schools , a(Match_ID) cl(town_id) 
qui eststo: reghdfe lnNoWRO Schools that  , noabsorb cl(town_id) 
qui eststo: reghdfe lnNoWRO Schools , a(Match_ID) cl(town_id) 
qui eststo: reghdfe lnNoWRO Schools that  , a(Match_ID) cl(town_id) 
qui eststo: reghdfe lnNoWRO Schools that lnDW lnDistBoundary  Spring_1650 Summer_1650 Fall_1650 Winter_1650  ///
		lnPop Hanse bishop Jewish Progrom Battle OldSchool Uni_1650 MR_2 Catholic  , a(Match_ID) cl(town_id) 
esttab, keep(Schools that)

/*
Results are the same when using weights - but due to the conceptual simplicity of using MAtch fixed effects,
that compare within a treated and a control observation that are ex ante similar,
we continue using Match Fixed effects.
*/


local varlist Share_NonRoyalReligion Share_Royals lnPop lnDW lnDistBoundary  Spring_1650 Summer_1650 Fall_1650 Winter_1650 Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 Catholic
local m : list sizeof local(varlist)
di `m'

la var Share_NonRoyalReligion "Share non-noble secular women"
la var Share_Royals "Share noble women"

mat Balance = J(`m',6,.)
mat rownames Balance = `varlist'
mat list Balance

local r = 0
qui foreach var of local varlist {
	local ++r	
	
	reghdfe `var' GirlSchool , noabsorb cl(town_id) 
		mat Balance[`r',1]=_b[GirlSchool]
		mat Balance[`r',2]=_se[GirlSchool]
		mat Balance[`r',3]=(2*(1-normal(abs(_b[GirlSchool]/_se[GirlSchool]))))
	reghdfe `var' GirlSchool , a(Match_ID) cl(town_id) 
		mat Balance[`r',4]=_b[GirlSchool]
		mat Balance[`r',5]=_se[GirlSchool]
		mat Balance[`r',6]=(2*(1-normal(abs(_b[GirlSchool]/_se[GirlSchool]))))		
}


esttab matrix(Balance,fmt(%9.3f) ) using "$tables/H4_Panel" ///
			, replace booktabs nomtitles  eqlabels(,merge)
			

			
			

foreach var of varlist 	LB Zeno WRO_Allgemein  MP_Weimar  {
eststo clear
	 qui {

		eststo: reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local matching ""
			
		eststo: reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if abs(Dist_Boundary)<10  /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10
			estadd local matching ""
			
		eststo: reghdfe `var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic Match_ID) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local matching "Yes"
			
				
		eststo: reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local matching ""
			
		eststo: reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 if abs(Dist_Boundary)<10  /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10
			estadd local matching ""
			
		eststo: reghdfe lnNo`var' Schools lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 /// 
			, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic Match_ID) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local matching "Yes"				
	
			
			
	}

	esttab, keep(Schools) se star(* 0.1 ** 0.05 *** 0.01) stats(N r2 MEAN Oster, fmt( %9.0fc %9.3f %9.3f)) 
		
		// for export	
	esttab using "$tables/H3_`var'.tex" ///
			, keep(Schools) replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (Schools "Finishing schools") ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _) 
			
		}
		//

// bring panels together
#delimit ;
esttab using "$tables/H3_Panel.tex", replace booktabs
	cells(none) nonote noobs nomtitles ///
	mgroups("\$\mathbb{I}[>0]\$" "log Number" , pattern(1 0 0 1 0 0) 
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
	prefoot(
	\multicolumn{@span}{l}{\emph{Panel A: Encyclopedia of female writers }} \\ 
	\panelinput{"Tables/H3_Zeno"} 
	\midrule \multicolumn{@span}{l}{\emph{Panel B: Leserbriefe, Frauenzeitung, 1849--1852 }} \\ 
	\panelinput{"Tables/H3_LB"} 
	\midrule \multicolumn{@span}{l}{\emph{Panel C: Women's rights organizations}} \\ 
	\panelinput{"Tables/H3_WRO_Allgemein"} 
	\midrule \multicolumn{@span}{l}{\emph{Panel D: Member Parliament, 1919--1933}} \\ 
	\panelinput{"Tables/H3_MP_Weimar"} \midrule )
	substitute(\_ _)	
stats(econ rel education  matching ///
N bw , label( "City Covariates"	"Religious covariates" "Educational covariates" "Propensity score matching" ///
"Observations" "Bandwidth" ) fmt(a a a a %9.0fc %9.0fc %9.0f )) ///
coeflabels (Schools "Finishing schools")
;
#delimit cr		