
*****************
* Schools are the reduced form effect. What would be the implied IV coefficient? 
* Instrument by schools existing in 1800
*****************		

use "$data/DNB_CrossSection.dta", clear
drop School*

use "$data/DNB_Panel.dta", clear
keep if Century==18
keep town_id School
merge 1:1 town_id using "$data/DNB_CrossSection.dta"
drop _merge


local endovar = "lnNonRoyalReligion"
local instrument ="School"

foreach var of varlist 	LB Zeno  WRO_Allgemein MP_Weimar  {
eststo clear
	 qui {
		*OLS:
		eststo: reghdfe `var' `endovar' /// 
			, noabsorb cl(town_id)					
		
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			
		eststo: reghdfe `var' `endovar' lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
				, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2 Catholic ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10

		*IV:			
			
		eststo: ivreghdfe `var'   ///
				(`endovar' = `instrument' ) /// 
			 /// 
			,  cl(town_id)	
			
		eststo: ivreghdfe `var'  lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
				(`endovar' = `instrument' ) ///
				, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10
		*OLS:
		eststo: reghdfe lnNo`var' `endovar' /// 
			, noabsorb cl(town_id)					
		
			estadd local econ ""
			estadd local rel ""
			estadd local education ""

			
		eststo: reghdfe lnNo`var' `endovar' lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
				, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
		
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10

		*IV:			
			
		eststo: ivreghdfe lnNo`var'   ///
				(`endovar' = `instrument'  ) /// 
			 /// 
			,  cl(town_id)	
			
		eststo: ivreghdfe lnNo`var'  lnDW lnDistBoundary lnPop Spring_1650 Summer_1650 Fall_1650 Winter_1650 ///
				(`endovar' = `instrument'  ) /// 
				, a(Hanse bishop Jewish Progrom Battle  OldSchool Uni_1650 MR_2  ) cl(town_id)	
			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"
			estadd local bw = 10

	}

	esttab, keep(`endovar' ) se star(* 0.1 ** 0.05 *** 0.01) stats(econ rel education ///
		N rkf, label( "City Covariates"	"Religious covariates" "Educational covariates " ///
		"Observations" "First stage F-statistic" ) fmt(a a a %9.0fc %9.3f))
		
	
	

	// for export	
	esttab using "$tables/I1_`var'.tex" ///
			, keep(`endovar' ) replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels(lnNonRoyalReligion "log(Number Non-Noble Seculars)" ) ///
			nomtitles nonumbers noobs nonote nogaps noline  ///
			substitute(\_ _)  
}


// bring panels together
		#delimit ;
		esttab using "$tables/I1_Panel.tex", replace booktabs
			cells(none) nonote noobs mtitles(OLS OLS IV IV OLS OLS IV IV) ///
			mgroups("\$\mathbb{I}[>0]\$" "log Number" , pattern(1 0 0 0 1 0 0 0 ) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Encyclopedia of female writers }} \\ 
			\panelinput{"Tables/I1_Zeno"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel B: Leserbriefe, Frauenzeitung, 1849--1852 }} \\ 
			\panelinput{"Tables/I1_LB"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel C: Women's rights organizations}} \\ 
			\panelinput{"Tables/I1_WRO_Allgemein"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel D: Member Parliament, 1919--1933}} \\ 
			\panelinput{"Tables/I1_MP_Weimar"} 
			\midrule )				
			substitute(\_ _)	
		stats(econ rel education ///
		N rkf, label( "City Covariates"	"Religious covariates" "Educational covariates " ///
		"Observations" "First stage F-statistic" ) fmt(a a a %9.0fc %9.3f)) ///
		coeflabels (Schools "Finishing schools")
		;
		#delimit cr
		