
* Produce Figure 1.
* Define Program calling two data, one for 50 year and one for 25 year periods
cap program drop produce_graph
program produce_graph 
	syntax,  fe(str) omit(str) p(str)

	use "$data/Figure_1_`p'.dta", clear
	tab Period

	cap drop Lead_Lag*
	
	gen Window=.

	su Period
	local n = 0 
	qui forvalues t = `r(min)'(1)`r(max)'{

		replace Window = `t' if Period==`t'

	}

	
	cap drop Pre_* 
	gen Lead_Lag = .


	su Period
	local min = `r(min)'+1	//First period needs to be dropped
	local n = 0 

	*** Create Pre-Values (until -1)
	qui forvalues t = `min'(1)-1 {
		di `t'
		replace Lead_Lag = `n' if Period==`t'

		local t = abs(`t')
		gen Pre_`t' = (Lead_Lag==`n')
		la var Pre_`t' "`t'"
		local n = `n'+1
	}



	cap drop Post_* 
	su Period

	*** Create Post-Values (0-max)
	qui forvalues t = 0(1)`r(max)'{
		di `t'
		replace Lead_Lag = `n' if Period==`t'
		
		gen Post_`t' = (Lead_Lag==`n')
		la var Post_`t' "`t'"
		local n = `n'+1
	}

	local o = abs(`omit')	// Omitted period
	drop Pre_`o'				// Dropping women aged 25-50
	keep if Century<=1950	// And dropping irrelevant periods


	**********************************************************************
	**** First Analysis:
	**********************************************************************

	*** Fixed Effects:

	 gen CENT100 	= round(Century,100)
	 gen CENT50		= round(Century,50)
	 gen CENT60  	= round(Century,60)
	 gen CENT30  	= round(Century,30)
	 gen CENT25  	= round(Century,25)
	 gen CENT20  	= round(Century,20)
	 

	qui tab Window
	mat LL = J(`r(r)',8,.)

	*** Regression:
	qui eststo: reghdfe NonRoyalReligion_D   Pre_* Post_*  if Window!=. , a(town_id `fe') cl(town_id)


	local n1 = 0
	su Period
	local min = `r(min)'+1	
	forvalues c = `min'(1)`r(max)' {
		local n1 = `n1'+1
		di `c'
		local n = abs(`c')
		if `c'<`omit'  {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=_b[Pre_`n']
			mat LL[`n1',3]=_b[Pre_`n']+1.64*_se[Pre_`n']
			mat LL[`n1',4]=_b[Pre_`n']-1.64*_se[Pre_`n']
		}
		if `c'==`omit' {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
			if `c'>`omit'&`c'<0  {
				mat LL[`n1',1]=`c'
				mat LL[`n1',2]=_b[Pre_`n']
				mat LL[`n1',3]=_b[Pre_`n']+1.64*_se[Pre_`n']
				mat LL[`n1',4]=_b[Pre_`n']-1.64*_se[Pre_`n']
			}	
			if `c'>`omit'&`c'>=0  {
				mat LL[`n1',1]=`c'
				mat LL[`n1',2]=_b[Post_`n']
				mat LL[`n1',3]=_b[Post_`n']+1.64*_se[Post_`n']
				mat LL[`n1',4]=_b[Post_`n']-1.64*_se[Post_`n']
			}	
		local n = `n'+1

	}


	*** Control Group Royals:
	qui eststo: reghdfe Royals_D   Pre_* Post_*  if Window!=.&`fe'<=1950 , a(town_id `fe') cl(town_id)


		local n1 = 0
		su Period
		local min = `r(min)'+1	
		local dmax = `r(max)'
		local dmin = `r(min)'+1
		forvalues c = `min'(1)`r(max)' {
			local n1 = `n1'+1
			di `c'
			local n = abs(`c')
			if `c'<`omit'  {
				mat LL[`n1',5]=`c'
				mat LL[`n1',6]=_b[Pre_`n']
				mat LL[`n1',7]=_b[Pre_`n']+1.64*_se[Pre_`n']
				mat LL[`n1',8]=_b[Pre_`n']-1.64*_se[Pre_`n']
			}
			if `c'==`omit' {
				mat LL[`n1',5]=`c'
				mat LL[`n1',6]=0
				mat LL[`n1',7]=0
				mat LL[`n1',8]=0
			}
			if `c'>`omit'&`c'<0  {
				mat LL[`n1',5]=`c'
				mat LL[`n1',6]=_b[Pre_`n']
				mat LL[`n1',7]=_b[Pre_`n']+1.64*_se[Pre_`n']
				mat LL[`n1',8]=_b[Pre_`n']-1.64*_se[Pre_`n']
			}	
			if `c'>`omit'&`c'>=0  {
				mat LL[`n1',5]=`c'
				mat LL[`n1',6]=_b[Post_`n']
				mat LL[`n1',7]=_b[Post_`n']+1.64*_se[Post_`n']
				mat LL[`n1',8]=_b[Post_`n']-1.64*_se[Post_`n']
			}		
			local n = `n'+1

		}


		mat list LL
		cap drop LL*
		svmat LL	

		reghdfe NonRoyalReligion_D  School_Dummy if Window!=.&`fe'<=1950 , a(town_id `fe') cl(town_id)
		
		local b = round(_b[School_Dummy],0.001)
		local se = round(_se[School_Dummy],0.001)
		
		qui su LL1
		// with Teachers
		twoway (line LL2 LL1) (rcap LL3 LL4 LL1) (line LL6 LL5) ///
		, yline(0) xlabel(`r(min)'(1)`r(max)') ///
		legend(order( 1 "Non-Noble Seculars" 3 "Nobility") ) ///
		xtitle(Periods) ytitle("`: variable label NonRoyalReligion_D'") ///
		note("Point estimate on Non-Noble Seculars: 0`b' (0`se')") ///
		legend(position(6) cols(3) size(medsmall)) 
		
		

		
	*** Label definitions:

		cap label drop ageatschool20
		label def ageatschool20 -20 "400-380"
		label def ageatschool20 -19 "380-360", add
		label def ageatschool20 -18 "360-340", add
		label def ageatschool20 -17 "340-320", add
		label def ageatschool20 -16 "320-300", add
		label def ageatschool20 -15 "300-280", add
		label def ageatschool20 -14 "280-260", add
		label def ageatschool20 -13 "260-240", add
		label def ageatschool20 -12 "240-220", add
		label def ageatschool20 -11 "220-200", add
		label def ageatschool20 -10 "200-180", add
		label def ageatschool20 -9 "180-160", add
		label def ageatschool20 -8 "160-140", add
		label def ageatschool20 -7 "140-120", add
		label def ageatschool20 -6 "120-100", add
		label def ageatschool20 -5 "100-80", add
		label def ageatschool20 -4 "80-60", add
		label def ageatschool20 -3 "60-40", add
		label def ageatschool20 -2 "40-20", add
		label def ageatschool20 -1 "20-0", add
		label def ageatschool20 0 "0", add
		label def ageatschool20 1 "-20", add
		label def ageatschool20 2 "-40", add
		label def ageatschool20 3 "-60", add
		label def ageatschool20 4 "-80", add
		label def ageatschool20 5 "-100", add
		label def ageatschool20 6 "-120", add
		label def ageatschool20 7 "-140", add

		cap label drop ageatschool25
		label def ageatschool25 -16 "400-375"
		label def ageatschool25 -15 "375-350", add
		label def ageatschool25 -14 "350-325", add
		label def ageatschool25 -13 "325-300", add
		label def ageatschool25 -12 "300-275", add
		label def ageatschool25 -11 "275-250", add
		label def ageatschool25 -10 "250-225", add
		label def ageatschool25 -9 "225-200", add
		label def ageatschool25 -8 "200-175", add
		label def ageatschool25 -7 "175-150", add
		label def ageatschool25 -6 "150-125", add
		label def ageatschool25 -5 "125-100", add
		label def ageatschool25 -4 "100-75", add
		label def ageatschool25 -3 "75-50", add
		label def ageatschool25 -2 "50-25", add
		label def ageatschool25 -1 "25-0", add
		label def ageatschool25 0 "0", add
		label def ageatschool25 1 "-25", add
		label def ageatschool25 2 "-50", add
		label def ageatschool25 3 "-75", add
		label def ageatschool25 4 "-100", add
		label def ageatschool25 5 "-125", add
		label def ageatschool25 6 "-150", add
		
		cap label drop ageatschool50
		label def ageatschool50 -7 "300-350", add
		label def ageatschool50 -6 "250-300", add
		label def ageatschool50 -5 "200-250", add
		label def ageatschool50 -4 "150-200", add			
		label def ageatschool50 -3 "100-150", add
		label def ageatschool50 -2 "100-50", add
		label def ageatschool50 -1 "50-0", add
		label def ageatschool50 0 "0", add
		label def ageatschool50 1 "-50", add
		label def ageatschool50 2 "-100", add
		label def ageatschool50 3 "-150", add
		

		

			label values LL1 ageatschool`p'
			label values LL5 ageatschool`p'
			twoway (line LL2 LL1) (rcap LL3 LL4 LL1) (line LL6 LL5) ///
			, yline(0) xlabel(`dmin'(1)`dmax', labels angle(ninety) valuelabel) ///
			legend(order( 1 "Non-Noble Seculars" 3 "Nobility") ) ///
			xtitle(Periods) ytitle("`: variable label NonRoyalReligion_D'") ///
			note("Point estimate on Non-Noble Seculars: 0`b' (0`se')") ///
			legend(position(6) cols(3) size(medsmall)) 

	
end 


* Figure 1:
produce_graph, fe(CENT50) omit(-2) p(25)

graph export "$figures/Figure_1.png", replace width(2000)
graph export "$figures/Figure_1.eps", replace  as(eps)
graph export "$figures/Figure_1.jpg", replace width(2000) as(jpg)

*** Appendix Figures C, 25 year periods:
* C3b:
produce_graph, fe(CENT100) omit(-2) p(25)
graph export "$figures/C3b_Figure.png", replace width(2000)
* C3d:
produce_graph, fe(CENT50) omit(-2) p(25)
graph export "$figures/C3d_Figure.png", replace width(2000)
* C3f:
produce_graph, fe(CENT25) omit(-2) p(25)
graph export "$figures/C3f_Figure.png", replace width(2000)

*** Appendix Figures C, 50 year periods:
* C3a:
produce_graph, fe(CENT100) omit(-2) p(50)
graph export "$figures/C3a_Figure.png", replace width(2000)
* C3c:
produce_graph, fe(CENT50) omit(-2) p(50)
graph export "$figures/C3c_Figure.png", replace width(2000)
* C3e:
produce_graph, fe(CENT25) omit(-2) p(50)
graph export "$figures/C3e_Figure.png", replace width(2000)
