
use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Figure 3: Cross-gender impact of male and female schools
//------------------------------------------------------------------------	

*************
* Main Figure
*************

*** Finishing School on Woman
sort town_id Century
cap drop NRR_MD 
gen NRR_MD = (NonRoyalReligion_M>0)

cap drop TW_MD 
gen TW_MD = (M_TW>0)
cap drop Writer_MD 
gen Writer_MD = (M_Writer>0)

cap drop Royals_MD 
gen Royals_MD = (M_Royals>0)

cap drop NRR_D
gen NRR_D = NonRoyalReligion_D	


mat LL = J(12,20,.)


*** Female Treatment


cap drop Treat
cap drop Lag
cap drop Lag_End
gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
gen Lag = Century if Treat==0
bysort town_id: egen Lag_End = max(Lag)
sort town_id CENT
replace Lag = Century-Lag_End

cap drop Lead_Lag*
cap drop Window
cap drop wlabel
gen Lead_Lag = .
gen Window = 0 if Treat==0
cap drop LeadLag_*

local n = 0 
qui forvalues t = -4(0.5)1.5 {
	replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
	replace Window = `t' if Lag==`t'&Lag_End!=.
	*label define wlabel `n' "`t'", add
	gen LeadLag_`n' = (Lead_Lag==`n')
	la var LeadLag_`n' "`t'"
	local n = `n'+1
}





// Men
eststo clear
eststo: reghdfe NRR_MD ///
		LeadLag_1 LeadLag_2 LeadLag_3 LeadLag_4 LeadLag_5 LeadLag_6  ///
		LeadLag_8 LeadLag_9 LeadLag_10 LeadLag_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

	

local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',1]=`c'-0.1
		mat LL[`n1',2]=0
		mat LL[`n1',3]=0
		mat LL[`n1',4]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',1]=`c'-0.1
		mat LL[`n1',2]=_b[LeadLag_`n1']
		mat LL[`n1',3]=_b[LeadLag_`n1']+1.96*_se[LeadLag_`n1']
		mat LL[`n1',4]=_b[LeadLag_`n1']-1.96*_se[LeadLag_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',1]=`c'-0.1
		mat LL[`n1',2]=0
		mat LL[`n1',3]=0
		mat LL[`n1',4]=0
	}
	local n = `n'+1
}
		
// Women
eststo clear
eststo: reghdfe NRR_D ///
		LeadLag_1 LeadLag_2 LeadLag_3 LeadLag_4 LeadLag_5 LeadLag_6  ///
		LeadLag_8 LeadLag_9 LeadLag_10 LeadLag_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

	

local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',5]=`c'
		mat LL[`n1',6]=0
		mat LL[`n1',7]=0
		mat LL[`n1',8]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',5]=`c'
		mat LL[`n1',6]=_b[LeadLag_`n1']
		mat LL[`n1',7]=_b[LeadLag_`n1']+1.96*_se[LeadLag_`n1']
		mat LL[`n1',8]=_b[LeadLag_`n1']-1.96*_se[LeadLag_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',5]=`c'
		mat LL[`n1',6]=0
		mat LL[`n1',7]=0
		mat LL[`n1',8]=0
	}
	local n = `n'+1
}		

	
*** Male Treatment


cap drop Treat
cap drop Lag
cap drop Lag_End
gen Treat = 0 if Male_School==1&Male_School[_n-1]==0
gen Lag = Century if Treat==0
bysort town_id: egen Lag_End = max(Lag)
sort town_id CENT
replace Lag = Century-Lag_End

cap drop Lead_Lag*
cap drop Window
cap drop wlabel
gen Lead_Lag = .
gen Window = 0 if Treat==0
cap drop LeadLag_*

local n = 0 
qui forvalues t = -4(0.5)1.5 {
	replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
	replace Window = `t' if Lag==`t'&Lag_End!=.
	*label define wlabel `n' "`t'", add
	gen LeadLag_`n' = (Lead_Lag==`n')
	la var LeadLag_`n' "`t'"
	local n = `n'+1
}





// Men
eststo clear
eststo: reghdfe NRR_MD ///
		LeadLag_1 LeadLag_2 LeadLag_3 LeadLag_4 LeadLag_5 LeadLag_6  ///
		LeadLag_8 LeadLag_9 LeadLag_10 LeadLag_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

	

local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',9]=`c'+0.1
		mat LL[`n1',10]=0
		mat LL[`n1',11]=0
		mat LL[`n1',12]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',9]=`c'+0.1
		mat LL[`n1',10]=_b[LeadLag_`n1']
		mat LL[`n1',11]=_b[LeadLag_`n1']+1.96*_se[LeadLag_`n1']
		mat LL[`n1',12]=_b[LeadLag_`n1']-1.96*_se[LeadLag_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',9]=`c'+0.1
		mat LL[`n1',10]=0
		mat LL[`n1',11]=0
		mat LL[`n1',12]=0
	}
	local n = `n'+1
}
		
// Women
eststo clear
eststo: reghdfe NRR_D ///
		LeadLag_1 LeadLag_2 LeadLag_3 LeadLag_4 LeadLag_5 LeadLag_6  ///
		LeadLag_8 LeadLag_9 LeadLag_10 LeadLag_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

	

local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',13]=`c'+0.2
		mat LL[`n1',14]=0
		mat LL[`n1',15]=0
		mat LL[`n1',16]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',13]=`c'+0.2
		mat LL[`n1',14]=_b[LeadLag_`n1']
		mat LL[`n1',15]=_b[LeadLag_`n1']+1.96*_se[LeadLag_`n1']
		mat LL[`n1',16]=_b[LeadLag_`n1']-1.96*_se[LeadLag_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',13]=`c'+0.2
		mat LL[`n1',14]=0
		mat LL[`n1',15]=0
		mat LL[`n1',16]=0
	}
	local n = `n'+1
}		

	

	
	
cap drop LL*
svmat LL

twoway (rspike LL3 LL4 LL1) (rspike LL7 LL8 LL5)  (rspike LL11 LL12 LL9) (rspike LL15 LL16 LL13) ///
	(line LL2 LL1) (line LL6 LL5)  (line LL10 LL9) (line LL14 LL13) ,	ylabel(-0.25(0.25)0.5)
*Finishing schools
	twoway (line LL2 LL1) (rcap LL3 LL4 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5)  /// 
	legend(order( 1 "Men"  ) ) ///
	xtitle(Century lags)  title("Finishing Schools") ///
	legend(position(6) cols(3) size(medsmall)) 
	graph save "$figures/g1.gph", replace
	twoway (line LL6 LL1) (rcap LL7 LL8 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5)  /// 
	legend(order( 1 "Women"  ) ) ///
	xtitle(Century lags)  title("Finishing Schools") ///
	legend(position(6) cols(3) size(medsmall)) 
	graph save "$figures/g2.gph", replace

*Male schools	
	twoway (line LL10 LL1) (rcap LL11 LL12 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(order( 1 "Men"  ) ) ///
	xtitle(Century lags)  title("Male Schools") ///
	legend(position(6) cols(3) size(medsmall)) 
	graph save "$figures/g3.gph", replace
	
	twoway (line LL14 LL1) (rcap LL15 LL16 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5)  /// 
	legend(order( 1 "Women"  ) ) ///
	xtitle(Century lags)  title("Male Schools") ///
	legend(position(6) cols(3) size(medsmall)) 
	graph save "$figures/g4.gph", replace	
	
	graph combine "$figures/g1.gph" "$figures/g2.gph" "$figures/g3.gph" "$figures/g4.gph", rows(2) ycommon ysize(10) xsize(12) iscale(0.5)
	
	graph export "$figures/Figure_3.png", replace width(2000)
	graph export "$figures/Figure_3.eps", replace  as(eps)
	graph export "$figures/Figure_3.jpg", replace width(2000) as(jpg)	
	
