
use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Figure 4: Impact of finishing schools on construction activity
//------------------------------------------------------------------------	
	
sort town_id Century
cap drop Growth_D lnGrowth
cap drop Const_D lnConst
gen Growth_D = (Growth>0)
gen lnGrowth = log(Growth+1)
gen Const_D = (Construction>0&Construction!=.)
gen lnConst = log(Construction+1)
cap drop Treat
cap drop Lag
cap drop Lag_End
gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
gen Lag = Century if Treat==0
bysort town_id: egen Lag_End = max(Lag)
sort town_id CENT
replace Lag = Century-Lag_End

cap drop Lead_Lag*
cap drop Window
cap drop wlabel
gen Lead_Lag = .
gen Window = 0 if Treat==0
cap drop T_LL_*

local n = 0 
qui forvalues t = -4(0.5)1.5 {
	replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
	replace Window = `t' if Lag==`t'&Lag_End!=.
	*label define wlabel `n' "`t'", add
	gen T_LL_`n' = (Lead_Lag==`n')
	la var T_LL_`n' "`t'"
	local n = `n'+1
}



// Non-Royals
eststo clear
eststo: reghdfe Const_D ///
	T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
	T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
	if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
				OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

	
mat LL = J(12,10,.)
local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',1]=`c'
		mat LL[`n1',2]=0
		mat LL[`n1',3]=0
		mat LL[`n1',4]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',1]=`c'
		mat LL[`n1',2]=_b[T_LL_`n1']
		mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
		mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',1]=`c'
		mat LL[`n1',2]=0
		mat LL[`n1',3]=0
		mat LL[`n1',4]=0
	}
	local n = `n'+1
}

	
// Royals
eststo clear
eststo: reghdfe lnConst ///
	T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
	T_LL_8 T_LL_9 T_LL_10 T_LL_11  ///
	if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
				OldSchool##Century Uni_1650#Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 


local n = 0
local n1 = 0
forvalues c = -3.5(0.5)1.5 {
	local n1 = `n1'+1
	if `c' == -4 {
		mat LL[`n1',5]=0
		mat LL[`n1',6]=0
		mat LL[`n1',7]=0
	}
	if `c'!=-0.5 & `c'!=-4 {
		mat LL[`n1',5]=_b[T_LL_`n1']
		mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
		mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
	}
	if `c'==-0.5 {
		mat LL[`n1',5]=0
		mat LL[`n1',6]=0
		mat LL[`n1',7]=0
	}
	local n = `n'+1
}


mat list LL
cap drop LL*
svmat LL	

// Construction (>0)
twoway (line LL2 LL1) (rcap LL3 LL4 LL1)  ///
, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
legend(order( 1 "Impact of School Construction"  2 "95% Confidence intervals") rows(2)) ///
xtitle(Century lags)  title("Construction") ///
legend(position(6) cols(3) size(medsmall)) 
	
graph save "$figures/g1.gph", replace


// # Construction
twoway (line LL5 LL1) (rcap LL6 LL7 LL1)  ///
, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
legend(order( 1 "Impact of School Construction"  2 "95% Confidence intervals") rows(2)) ///
xtitle(Century lags)  title("log Number of Buildings Constructed") ///
legend(position(6) cols(3) size(medsmall)) 	

graph save "$figures/g2.gph", replace

graph combine "$figures/g1.gph" "$figures/g2.gph", rows(1) ycommon





	graph export "$figures/Figure_4a.png", replace width(2000)
	graph export "$figures/Figure_4a.eps", replace  as(eps)
	graph export "$figures/Figure_4a.jpg", replace width(2000) as(jpg)	




*** Demand?

su Pop_Panel 
foreach var of varlist Pop_Panel  { 
preserve
	
	*** Preparation -- variable definition


	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}
	
	// Non-Royals
	eststo clear
	eststo: reghdfe `var' ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		, a(town_id CENT ) cl(town_id)
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p1 = `r(p)'
		
	mat LL = J(12,10,.)
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=_b[T_LL_`n1']
			mat LL[`n1',3]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2]=0
			mat LL[`n1',3]=0
			mat LL[`n1',4]=0
		}
		local n = `n'+1
	}
	
	
	// Royals
	eststo: reghdfe `var' ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		,a(Century town_id ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		test T_LL_1+ T_LL_2+ T_LL_3+ T_LL_4+ T_LL_5+ T_LL_6 = T_LL_8+ T_LL_9+ T_LL_10+ T_LL_11
		local p2 = `r(p)'
	
	local n = 0
	local n1 = 0
	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',5]=_b[T_LL_`n1']
			mat LL[`n1',6]=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',7]=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',5]=0
			mat LL[`n1',6]=0
			mat LL[`n1',7]=0
		}
		local n = `n'+1
	}
	
	

	mat list LL
	cap drop LL1-LL10
	svmat LL	

	gen LL_1 = 0
	replace LL_1 = LL1-0.025 if LL1!=0
	gen LL_2 = 0 
	replace LL_2 = LL1+0.025 if LL1 !=0
	
	local pp1 : di %4.3f `p1'
	local pp2 : di %4.3f `p2'
	
	twoway (line LL2 LL_1) (rcap LL3 LL4 LL_1) ///
	(line LL5 LL_2, lcolor(gs8) lpattern(longdash_dot)) (rcap LL6 LL7 LL_2, lcolor(gs8) lpattern(longdash_dot)) ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(off ) note("p-value leads = lags: `pp1' without covariates and `pp2' with covariates") ///
	xtitle(Century lags) 
	
	
	graph export "$figures/Figure_4b.png", replace width(2000)
	graph export "$figures/Figure_4b.eps", replace  as(eps)
	graph export "$figures/Figure_4b.jpg", replace width(2000) as(jpg)	
	
restore	
}