use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Figure 5: Impact of cultural change on notable women
//------------------------------------------------------------------------		
	

*** Create Witch trials
gsort town_id -CENT //To have them reversely sorted
cap drop Treat
cap drop Lag
cap drop WT
cap drop Lag_End
cap drop End_WT
bysort town_id: gen WT = sum(WitchTrial)
replace WT = 1 if WT>0

sort town_id Century
gen End_WT = 0
replace End_WT =1 if WT[_n-1]==1&WT==0
bysort town_id: replace End_WT = sum(End_WT)


*** Create Monasteries
sort town_id CENT // Sort
cap drop M_Treat
cap drop MW
drop if Century==.
local cutoff = 13
bysort town_id: gen M_Treat = sum(Monastries_Women_Founded) if Century>=`cutoff'
replace M_Treat = 1 if M_Treat>0
replace M_Treat = 0 if Century<=`cutoff'

*** Create First Kirchweihe 
sort town_id CENT // Sort
cap drop KW_Treat
cap drop KW
drop if Century==.
gen KW = (KirchWeihe>0&Century>=16.5)

bysort town_id: gen KW_Treat = sum(KW)
replace KW_Treat = 1 if KW_Treat>0



*** Create Reformation
sort town_id CENT // Sort
cap drop R_Treat
cap drop RF
drop if Century==.
gen RF = Reformation 
bysort town_id: gen R_Treat = sum(RF)
replace R_Treat = 1 if R_Treat>0


	

mat LL = J(12,13,.)

local r=0
foreach dvar of varlist  End_WT M_Treat  KW_Treat  {
	local n = 0
	local n1 = 0

	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if `dvar'==1&`dvar'[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}
	
	

	// Non-Royals
	eststo clear
	eststo: reghdfe NonRoyalReligion_D ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		,a(Century town_id ///
				Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
				Battle##Century c.lnDW##Century ///
				c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
				c.Winter_1650##Century ///
				c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
				MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		

	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=0
			mat LL[`n1',3+`r']=0
			mat LL[`n1',4+`r']=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=_b[T_LL_`n1']
			mat LL[`n1',3+`r']=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4+`r']=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=0
			mat LL[`n1',3+`r']=0
			mat LL[`n1',4+`r']=0
		}
		local n = `n'+1
	}
	local r = `r'+3
	di `r'
}	
	

	

foreach dvar of varlist  R_Treat  {
	local n = 0
	local n1 = 0

	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	gen Treat = 0 if `dvar'==1&`dvar'[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End

	cap drop Lead_Lag*
	cap drop Window
	cap drop wlabel
	gen Lead_Lag = .
	gen Window = 0 if Treat==0
	cap drop T_LL_*
	
	local n = 0 
	qui forvalues t = -4(0.5)1.5 {
		replace Lead_Lag = `n' if Lag==`t'&Lag_End!=.
		replace Window = `t' if Lag==`t'&Lag_End!=.
		*label define wlabel `n' "`t'", add
		gen T_LL_`n' = (Lead_Lag==`n')
		la var T_LL_`n' "`t'"
		local n = `n'+1
	}
	
	

	// Non-Royals
	eststo clear
	eststo: reghdfe NonRoyalReligion_D ///
		T_LL_1 T_LL_2 T_LL_3 T_LL_4 T_LL_5 T_LL_6  ///
		T_LL_8 T_LL_9 T_LL_10 T_LL_11   ///
		if Window!=. ///
		,a(Century town_id ///
				Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
				Battle##Century c.lnDW##Century ///
				c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
				c.Winter_1650##Century ///
				c.lnPop##Century ///
					OldSchool##Century Uni_1650#Century ///
				) cl(town_id) 
		

	forvalues c = -3.5(0.5)1.5 {
		local n1 = `n1'+1
		if `c' == -4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=0
			mat LL[`n1',3+`r']=0
			mat LL[`n1',4+`r']=0
		}
		if `c'!=-0.5 & `c'!=-4 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=_b[T_LL_`n1']
			mat LL[`n1',3+`r']=_b[T_LL_`n1']+1.96*_se[T_LL_`n1']
			mat LL[`n1',4+`r']=_b[T_LL_`n1']-1.96*_se[T_LL_`n1']
		}
		if `c'==-0.5 {
			mat LL[`n1',1]=`c'
			mat LL[`n1',2+`r']=0
			mat LL[`n1',3+`r']=0
			mat LL[`n1',4+`r']=0
		}
		local n = `n'+1
	}
	local r = `r'+3
	di `r'
}	
	

	mat list LL
	cap drop LL*
	svmat LL	
	
	// Witches
	twoway (line LL2 LL1) (rcap LL3 LL4 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(order( 1 "Non-Noble Secular"  ) rows(2)) ///
	xtitle(Century lags)  title("End of Witch Trials") ///
	legend(position(6) cols(3) size(medsmall)) 
		
	graph save "$figures/g1.gph", replace
	
	
	// Monasteries
	twoway (line LL5 LL1) (rcap LL6 LL7 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(order( 1 "Non-Noble Secular"  ) rows(2)) ///
	xtitle(Century lags)  title("Opening of Female Monastery") ///
	legend(position(6) cols(3) size(medsmall)) 
		
	graph save "$figures/g2.gph", replace
	
	// Kirchweihen
	twoway (line LL8 LL1) (rcap LL9 LL10 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(order( 1 "Non-Noble Secular"  ) rows(2)) ///
	xtitle(Century lags)  title("Church consecration") ///
	legend(position(6) cols(3) size(medsmall)) 
	
	graph save "$figures/g3.gph", replace	
	
	// Timing of Reformation
	twoway (line LL11 LL1) (rcap LL12 LL13 LL1)  ///
	, yline(0) xline(-0.5) xlabel(-3.5(0.5)1.5) /// 
	legend(order( 1 "Non-Noble Secular"  ) rows(2)) ///
	xtitle(Century lags)  title("Reformation in city") ///
	legend(position(6) cols(3) size(medsmall)) 	
		
	graph save "$figures/g4.gph", replace	
	
	graph combine "$figures/g1.gph" "$figures/g2.gph" "$figures/g3.gph" "$figures/g4.gph", rows(2) ycommon 
	
	
	

	
	graph export "$figures/Figure_5.png", replace width(2000)
	graph export "$figures/Figure_5.eps", replace  as(eps)
	graph export "$figures/Figure_5.jpg", replace width(2000) as(jpg)		

	*	
