
use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Table 2 Placebo estimates on the importance of finishing schools: Differential returns to education
//------------------------------------------------------------------------
*****************
* Table main text
*****************

*First Panel Finishing Schools:
	
cap drop Royals_MD
cap drop NRR_D NRR_DM
gen NRR_D = NonRoyalReligion_D	
gen NRR_DM = (NonRoyalReligion_M>0)

/*
cap drop UnM_D UnM_DM
gen UnM_D = (UnMarried>0)
gen UnM_DM = (M_UnMarried>0)
*/
cap drop TW_DM 
gen TW_DM = (M_TW>0)
cap drop Writer_DM
gen Writer_DM = (M_Writer>0)

cap drop Royals_DM
gen Royals_DM = (M_Royal>0)

cap drop Male_School_Dummy
gen Male_School_Dummy = (Male_School>0)




eststo clear
qui foreach var of varlist NRR_D   {


	*Female School
	sort town_id Century
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	cap drop Window
	gen Treat = 0 if School_Dummy==1&School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	gen Window = .
	replace Window = 1 if Lag>=-4&Lag<2
	

	eststo: reghdfe `var' School_Dummy ///
			if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id)

		estadd local econ "Yes"
		estadd local rel "Yes"
		
	eststo: reghdfe `var'M School_Dummy ///
			if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		estadd local econ "Yes"
		estadd local rel "Yes"		

	preserve
	
		keep CENT town_id `var' `var'M School_Dummy Male_School Male_School_Dummy Window 
		
		keep if Window==1
		expand 2, gen(t)
		sort town_id CENT t
		gen Women = (t==0)
		gen Men = 1-Women
		gen NRR = `var' if Women==1
		replace NRR = `var'M if Women==0
		
		gen Finishing_Women = School_Dummy*Women

		
		eststo, pref(FS): reghdfe NRR Finishing_Women if Window!=., a(CENT##town_id Men##CENT) cl(town_id)
			estadd local c_d "Yes"		
			estadd local m_d "Yes"
			
	restore	
		
	
		
	*Male School	
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	cap drop Window
	sort town_id Century
	gen Treat = 0 if  Male_School_Dummy==1& Male_School_Dummy[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	gen Window = .
	replace Window = 1 if Lag>=-4&Lag<2

	eststo: reghdfe `var' Male_School_Dummy ///
			if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id)

		estadd local econ "Yes"
		estadd local rel "Yes"
		
	eststo: reghdfe `var'M Male_School_Dummy ///
			if Window!=. ///
			,a(Century town_id ///
			Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
			Battle##Century c.lnDW##Century ///
			c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
			c.Winter_1650##Century ///
			c.lnPop##Century ///
			MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		estadd local econ "Yes"
		estadd local rel "Yes"		
	
	preserve
	
		keep CENT town_id `var' `var'M   Male_School_Dummy  Male_School_Dummy Window
		
		keep if Window==1
		expand 2, gen(t)
		sort town_id CENT t
		gen Women = (t==0)
		gen Men = 1-Women
		gen NRR = `var' if Women==1
		replace NRR = `var'M if Women==0
		
		
		gen BoySchool_Men= Men* Male_School_Dummy 
	
		
		eststo, pref(MS): reghdfe NRR BoySchool_Men , a(CENT##town_id Women##CENT) cl(town_id)
			estadd local c_d "Yes"		
			estadd local m_d "Yes"
	restore	
	
	}
		

	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
	mgroups("Non Royal" "Writer", pattern(1 0 1 0 )) ///
	mtitles("Women" "Men" "Women" "Men") ///
	stats( c_d m_d ///
	r2_a N , label( "City \(\times\) period FE" "Men \(\times\) period FE" ///
	"Adj. R2" "Observations" "F-Test") fmt(a a   %9.3f %9.0fc )) ///
	coeflabels(Finishing_Women "Girl school X women" ///
	BoySchool_Men "Boy school X Men" School_Dummy "Girl school" Male_School_Dummy "Boy school") noabbrev varwidth(35)


	
	esttab  using "$tables/T2_Cross.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels(Finishing_Women "Girl school X women" ///
	BoySchool_Men "Boy school X Men" School_Dummy "Girl school" Male_School_Dummy "Boy school") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _) 
			
	
			

// bring panels together
		#delimit ;
		esttab   using "$tables/T2_Panel.tex", replace booktabs
			cells(none) nonote noobs mtitles("Women" "Men" "Panel" "Women" "Men" "Panel") 
			mgroups("\multirow{2}{3cm}{\centering \emph{Access to female education}}}" "\multirow{2}{3cm}{\centering \emph{Access to male education}}} \\ "  , pattern(1 0 0 1 0 0  ) 
			prefix("\multicolumn{@span}{c}{")  span )
			prefoot(\panelinput{"Tables/T2_Cross"} 
			\midrule 	)
			substitute(\_ _)	
		stats(econ rel c_d m_d ///
	r2_a N , label("City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE"  "City \(\times\) period FE" "Men \(\times\) period FE" ///
	"Adj. R2" "Observations" "F-Test") fmt(a a a a  %9.3f %9.0fc )) ///
		;
#delimit cr	