
use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Table 3 Placebo estimates on the importance of finishing schools: Changing culture
//------------------------------------------------------------------------	

*** Create witch trial
gsort town_id -CENT //To have them reversely sorted
cap drop Treat
cap drop Lag
cap drop WT
cap drop Lag_End
cap drop End_WT
bysort town_id: gen WT = sum(WitchTrial)
replace WT = 1 if WT>0

sort town_id Century
gen End_WT = 0
replace End_WT =1 if WT[_n-1]==1&WT==0
bysort town_id: replace End_WT = sum(End_WT)

*** Create Monasteries
sort town_id CENT // Sort
cap drop M_Treat
cap drop MW
drop if Century==.
local cutoff = 13
bysort town_id: gen M_Treat = sum(Monastries_Women_Founded) if Century>=`cutoff'
replace M_Treat = 1 if M_Treat>0
replace M_Treat = 0 if Century<=`cutoff'

*** Create First Kirchweihe 
sort town_id CENT // Sort
cap drop KW_Treat
cap drop KW
drop if Century==.
gen KW = (KirchWeihe>0&Century>=16.5)

bysort town_id: gen KW_Treat = sum(KW)
replace KW_Treat = 1 if KW_Treat>0


*** Create Reformation
sort town_id CENT // Sort
cap drop R_Treat
cap drop RF
drop if Century==.
gen RF = Reformation 
bysort town_id: gen R_Treat = sum(RF)
replace R_Treat = 1 if R_Treat>0



foreach dvar of varlist  R_Treat {
	eststo clear	
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	cap drop Window
	gen Treat = 0 if `dvar'==1&`dvar'[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	gen Window = .
	replace Window = 1 if Lag>=-4&Lag<2
		
	qui foreach var of varlist NonRoyalReligion_D lnNonRoyalReligion Share_NonRoyalReligion  {

			eststo: reghdfe `var' `dvar' ///
				if Window!=. ///
				,a(Century town_id ) cl(town_id) 

				

			estadd local econ ""
			estadd local rel ""
			estadd local education ""	



					
			eststo: reghdfe `var' `dvar' ///
				if Window!=. ///
				,a(Century town_id ///
				Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
				Battle##Century c.lnDW##Century ///
				c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
				c.Winter_1650##Century ///
				c.lnPop##Century ///
				OldSchool##Century Uni_1650#Century ///
				) cl(town_id) 

				

			
			estadd local econ "Yes"
			estadd local rel ""
			estadd local education "Yes"
			

	

			}

		

		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats( econ rel education ///
		r2_a N , label("City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Adj. R2" "Observations" "F-Test") fmt(a a a   %9.3f %9.0fc )) ///
		coeflabels (School "Finishing school\(\_{it}\)"  SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post")
	
	// for export	
	esttab using "$tables/T3_`dvar'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy   "Finishing school\(\_{it}\)"  ///
				End_WT "End of Witch Trial\(\_{it}\)" R_Treat "Reformation in City\(\_{it}\)" /// 
				M_Treat "Female monastery opens\(\_{it}\)" KW_Treat "Consecration to a female saint\(\_{it}\)") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _)  stats( rel , label( "Religious covariates \(\times\) period FE" ) fmt(a )) 
			
	
			
}

	


foreach dvar of varlist  End_WT  M_Treat KW_Treat {
	eststo clear	
	cap drop Treat
	cap drop Lag
	cap drop Lag_End
	cap drop Window
	gen Treat = 0 if `dvar'==1&`dvar'[_n-1]==0
	gen Lag = Century if Treat==0
	bysort town_id: egen Lag_End = max(Lag)
	sort town_id CENT
	replace Lag = Century-Lag_End
	gen Window = .
	replace Window = 1 if Lag>=-4&Lag<2
		
	qui foreach var of varlist NonRoyalReligion_D lnNonRoyalReligion Share_NonRoyalReligion  {

			eststo: reghdfe `var' `dvar' ///
				if Window!=. ///
				,a(Century town_id ) cl(town_id) 

				

			estadd local econ ""
			estadd local rel ""
			estadd local education ""	



					
			eststo: reghdfe `var' `dvar' ///
				if Window!=. ///
				,a(Century town_id ///
				Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
				Battle##Century c.lnDW##Century ///
				c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
				c.Winter_1650##Century ///
				c.lnPop##Century ///
				OldSchool##Century Uni_1650#Century ///
				MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

				

			estadd local econ "Yes"
			estadd local rel "Yes"
			estadd local education "Yes"	

	

			}

		

		esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats( econ rel education ///
		r2_a N , label("City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Adj. R2" "Observations" "F-Test") fmt(a a a   %9.3f %9.0fc )) ///
		coeflabels (School "Finishing school\(\_{it}\)"  SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post")
	
	// for export	
	esttab using "$tables/T3_`dvar'.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy   "Finishing school\(\_{it}\)"  ///
				End_WT "End of Witch Trial\(\_{it}\)" R_Treat "Reformation in City\(\_{it}\)" /// 
				M_Treat "Female monastery opens\(\_{it}\)" KW_Treat "Consecration to a female saint\(\_{it}\)") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _)   stats( rel , label( "Religious covariates \(\times\) period FE" ) fmt(a )) 
	
			
}


		


			
* End_WT Q_Treat M_Treat
// bring panels together: Culture Table
		#delimit ;
		esttab using "$tables/T3_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles
			mgroups("\multirow{2}{3cm}{\centering \$\mathbb{I}[\textit{Non-Noble }\$ \$\textit{Secular}>0]\$}}" 
			"\multirow{2}{3cm}{\centering log \textit{Non-Noble Secular}}}" "\multirow{2}{3cm}{\centering Share \textit{Non-Noble Secular}}} \\ "  , pattern(1 0 1 0 1 0 1 0 ) 
			prefix("\multicolumn{@span}{c}{")  span )
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: End of witch trials}} \\ 
			\panelinput{"Tables/T3_End_WT"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel B: Creation of a female monastery}} \\ 			
			\panelinput{"Tables/T3_M_Treat"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel C: Church consecration to a female Saint}} \\ 			
			\panelinput{"Tables/T3_KW_Treat"} 
			\midrule \multicolumn{@span}{l}{\emph{Panel D: Reformation happening in city}} \\ 
			\panelinput{"Tables/T3_R_Treat"} \midrule )
			substitute(\_ _)		
		stats(econ  education ///
		, label( "City covariates \(\times\) period FE" ///
		"Educational covariates \(\times\) period FE" ///
		) fmt(a a a)) ///
		coeflabels (School_Dummy   "Finishing school\(\_{it}\)"  Male_School "Boy school\(\_{it}\)"  Uni "University\(\_{it}\)"  End_WT "End of Witch Trial\(\_{it}\)" )
		;
		#delimit cr
*
