
use "$data/DNB_Panel.dta", clear

cap drop LaborForce_Participation LaborForce_Participation_D Share_LaborForce_Participation lnLaborForce_Participation
egen LaborForce_Participation = rowtotal(Occupations Medicine Teacher Academic Writer )
gen LaborForce_Participation_D = (LaborForce_Participation>0) if LaborForce_Participation!=.
gen Share_LaborForce_Participation = (LaborForce_Participation)/(LaborForce_Participation+M_Occupation+1)
gen lnLaborForce_Participation = log(LaborForce_Participation+1)

eststo clear
foreach var of varlist   Writer Activist LaborForce_Participation   {


qui {
	
	
	
	* FE DUMMY
	
	 eststo: reghdfe `var'_D School_Dummy ,a(Century town_id##c.Century ) cl(town_id)
		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ ""
		estadd local rel ""
		estadd local education ""

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'		
	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
	eststo: reghdfe `var'_D School_Dummy ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 

		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"

		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		
				
	 
}
	// for inspection
	esttab, drop(_cons ) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
		stats(localitytrend econ rel education psmatch ///
		r2_a N MEAN, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" ///
		"Adj. R2" "Observations" "Mean") fmt(a a a a a %9.3f %9.0fc %9.3f)) ///
		coeflabels (School "Finishing school\(\_it\)" )
	// for export


	
}

	esttab using "Tables/T4_LFP.tex" ///
			, replace booktabs fragment ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabels (School_Dummy "Finishing school\$_{it}\$" SchoolD_Post "Finishing school x post" Mona_Post "Monasteries x post") ///
			nomtitles nonumbers noobs nonote nogaps noline drop(_cons) ///
			substitute(\_ _) ///
			stats(MEAN, label("Mean, untreated") fmt(%9.3f))	
// bring panels together
		#delimit ;
		esttab using "$tables/T4_Panel.tex", replace booktabs
			cells(none) nonote noobs nomtitles ///
			mgroups("Writers" "Activists" "Labor Force Participation", pattern(1 0 0 1 0 0 1 0 0 ) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
			prefoot(
			\panelinput{"Tables/T4_LFP.tex"} 
			\midrule  )
			substitute(\_ _)	
		stats(localitytrend econ rel education psmatch ///
		N, label( "Unit trend" "City covariates \(\times\) period FE" ///
		"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
		"Matching on 1600 covariates" "Observations" ) fmt(a a a a a %9.0fc )) ///
		coeflabels (School "Finishing school\(\_it\)" )
		;
		#delimit cr