
use "$data/DNB_Panel.dta", clear
//------------------------------------------------------------------------
*** Table 6 Impact of Writers:
//------------------------------------------------------------------------	

cap drop X_*
gen X_lnWirkWriter = School_Dummy*lnWirk_Writer
gen X_WirkWriter_D = School_Dummy*Wirk_Writer_D

replace Wirk_NonRoyalReligion = 0 if Wirk_NonRoyalReligion<0
replace Wirk_NonRoyalReligion_D=(Wirk_NonRoyalReligion>0)
replace lnWirk_NonRoyalReligion = log(Wirk_NonRoyalReligion+1)

replace Wirk_Politics = 0  if Wirk_Politics<0
replace Wirk_Politics_D = (Wirk_Politics>0)
replace lnWirk_Politics = log(lnWirk_Politics+1)

gen X_lnWirkNRR = School_Dummy*lnWirk_NonRoyalReligion
gen X_WirkNRR_D = School_Dummy*Wirk_NonRoyalReligion_D
gen X_lnWirkPol = School_Dummy*lnWirk_Politics
gen X_WirkPol_D = School_Dummy*Wirk_Politics_D


eststo clear
foreach var of varlist NonRoyalReligion  {

qui {
	
* DUMMY:		
eststo, pref(dum): reghdfe `var'_D  School_Dummy ///
		Wirk_NonRoyalReligion_D X_WirkNRR_D /// 
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 		
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
	
		
	eststo, pref(dum): reghdfe `var'_D  School_Dummy ///
		Wirk_NonRoyalReligion_D X_WirkNRR_D /// 
		Wirk_Politics_D X_WirkPol_D   ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		su Wirk_Politics_D if e(sample)&Post_30yr==1
		estadd scalar MEAN2 = `r(mean)'			
		
	eststo, pref(dum): reghdfe `var'_D  School_Dummy ///
		Wirk_NonRoyalReligion_D X_WirkNRR_D /// 
		Wirk_Writer_D X_WirkWriter_D   ///
		,a(Century town_id##c.Century Match_ID##Century ///
		Hanse##Century bishop##Century Jewish##Century Progrom##Century /// 
		Battle##Century c.lnDW##Century ///
		c.Spring_1650##Century c.Summer_1650##Century c.Fall_1650##Century ///
		c.Winter_1650##Century ///
		c.lnPop##Century ///
		OldSchool##Century Uni_1650#Century ///
		MR_2##Century Catholic##Century c.lnDistBoundary##Century) cl(town_id) 
		estadd local localityFE "Yes"
		estadd local localitytrend "Yes"
		estadd local econ "Yes"
		estadd local rel "Yes"
		estadd local education "Yes"
		estadd local psmatch "Yes"
		su `var'_D if School_Dummy==0&e(sample)&Post_30yr==1
		estadd scalar MEAN = `r(mean)'	
		su Wirk_Writer_D if e(sample)&Post_30yr==1
		estadd scalar MEAN2 = `r(mean)'		
	
		
	}

}

esttab, keep(School_Dummy X_*) star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se /// 
	stats(localitytrend econ rel education psmatch ///
	r2_a N MEAN MEAN2, label( "Unit trend" "City covariates \(\times\) period FE" ///
	"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" "Matching on 1600 covariates" ///
	"Adj. R2" "Observations" "Mean dependent variable" "Mean active writers") fmt(a a a a a %9.3f %9.0fc %9.3f %9.3f)) ///
	coeflabels (School "Finishing school\(\_it\)" X_WirkNRR_D "School \(\times\) Active Non-Noble Secular" X_WirkWriter_D "School \(\times\) Active Writer" )
// for export

esttab using "$tables/T6_NonRoyalReligion.tex" ///
	, keep(School_Dummy X_* ) replace booktabs fragment ///
	star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
	coeflabels (School_Dummy "Finishing school\$_{it}\$" X_WirkNRR_D "School \(\times\) Active Non-Noble Secular" X_WirkWriter_D "School \(\times\) Active Writer" X_WirkPol_D "School \(\times\) Active Politician") ///
	nomtitles nonumbers noobs nonote nogaps noline  ///
	substitute(\_ _) 
		
// bring panels together
#delimit ;
	esttab using "$tables/T6_Panel.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
					mgroups("\$\mathbb{I}[\textit{Non-Noble Secular}>0]\$" , pattern(1 0 0  ) 
			prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(
		\panelinput{"Tables/T6_NonRoyalReligion"} 
		\midrule)
		substitute(\_ _)	
	stats(localitytrend econ rel education psmatch N MEAN MEAN2 ///
	, label( "Unit trend" "City covariates \(\times\) period FE" ///
	"Religious covariates \(\times\) period FE" "Educational covariates \(\times\) period FE" ///
	"Matching on 1600 covariates" "Observations" "Mean dependent variable" "Mean active writers" ) fmt(a a a a a %9.0fc  %9.3f %9.3f)) ///
	coeflabels (School "Finishing school\(\_it\)" )
	;
#delimit cr			

